@@ -14,7 +14,7 @@ libtool=0
 gettext=0
 libtoolize=libtoolize
 
-if which glibtoolize >/dev/null; then
+if which glibtoolize >/dev/null 2>&1 ; then
     libtoolize=glibtoolize
 fi
 
