@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: charconv.h,v 1.9 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: charconv.h,v 1.11 2006/03/22 08:10:47 hoa Exp $
  */
 
 #ifndef CHARCONV_H
@@ -44,7 +44,7 @@ extern "C" {
 #include <sys/types.h>
 
 #ifndef LIBETPAN_CONFIG_H
-#	include "libetpan-config.h"
+#	include <libetpan/libetpan-config.h>
 #endif
 
 enum {
