@@ -30,17 +30,21 @@
  */
 
 /*
- * $Id: connect.c,v 1.12 2004/11/21 21:53:31 hoa Exp $
+ * $Id: connect.c,v 1.13 2005/06/01 12:21:57 smarinier Exp $
  */
 
 #include "connect.h"
 
 #include <sys/types.h>
 #include <string.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <unistd.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <netdb.h>
+#	include <netinet/in.h>
+#	include <sys/socket.h>
+#	include <unistd.h>
+#endif
 
 uint16_t mail_get_service_port(const char * name, char * protocol)
 {
@@ -80,7 +84,11 @@ int mail_tcp_connect(const char * server, uint16_t port)
   return s;
   
  close_socket:
+#ifdef WIN32
+  closesocket( s);
+#else
   close(s);
+#endif
  err:
   return -1;
 }
