@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream.c,v 1.16 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: mailstream.c,v 1.17 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mailstream.h"
@@ -394,7 +394,7 @@ ssize_t mailstream_feed_read_buffer(mailstream * s)
   return s->read_buffer_len;
 }
 
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC) 
 struct timeval mailstream_network_delay =
 {  DEFAULT_NETWORK_TIMEOUT, 0 };
 #else
