@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_low.c,v 1.15 2005/07/15 16:37:03 hoa Exp $
+ * $Id: mailstream_low.c,v 1.16 2005/11/02 17:31:18 hoa Exp $
  */
 
 #include "mailstream_low.h"
@@ -85,7 +85,7 @@ void (* mailstream_logger)(int direction,
 #define STREAM_LOG(direction, str) \
   if (mailstream_debug) { \
     if (mailstream_logger != NULL) { \
-      mailstream_logger(direction, str, strlen(str)); \
+      mailstream_logger(direction, str, strlen(str) + 1); \
     } \
     else { \
       FILE * f; \
