@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_socket.c,v 1.18 2005/06/01 14:34:51 hoa Exp $
+ * $Id: mailstream_socket.c,v 1.20 2005/11/07 08:53:32 hoa Exp $
  */
 
 #include "mailstream_socket.h"
@@ -49,6 +49,10 @@
 #	include <sys/socket.h>
 #endif
 
+#if HAVE_STRING_H
+#  include <string.h>
+#endif
+
 /*
   these 3 headers MUST be included before <sys/select.h>
   to insure compatibility with Mac OS X (this is true for 10.2)
@@ -71,7 +75,7 @@ static void mailstream_low_socket_free(mailstream_low * s);
 static int mailstream_low_socket_get_fd(mailstream_low * s);
 
 static mailstream_low_driver local_mailstream_socket_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC) || defined (__SUNPRO_C)
 	/* SEB */
 	mailstream_low_socket_read,
 	mailstream_low_socket_write,
