@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mmapstring.c,v 1.19 2005/01/31 01:07:50 hoa Exp $
+ * $Id: mmapstring.c,v 1.20 2005/06/01 12:21:57 smarinier Exp $
  */
 
 #include "mmapstring.h"
@@ -43,11 +43,17 @@
 #endif
 
 #include <stdlib.h>
-#include <unistd.h>
-#include <sys/mman.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <unistd.h>
+#	include <sys/mman.h>
+#endif
 #include <string.h>
 #ifdef LIBETPAN_REENTRANT
-#include <pthread.h>
+#	ifndef WIN32
+#		include <pthread.h>
+#	endif
 #endif
 
 #include "libetpan-config.h"
@@ -66,7 +72,34 @@ static size_t mmap_string_ceil = MMAP_STRING_DEFAULT_CEIL;
 /* MMAPString references */
 
 #ifdef LIBETPAN_REENTRANT
-static pthread_mutex_t mmapstring_lock = PTHREAD_MUTEX_INITIALIZER;
+#	ifdef WIN32
+
+		static	CRITICAL_SECTION mmapstring_lock ;
+		static  CRITICAL_SECTION* _get_critical() {
+					InitializeCriticalSection(&mmapstring_lock);
+					return &mmapstring_lock;
+				}
+		static	int	_lock_initialized = 0;
+		static void __mutex_lock(CRITICAL_SECTION* section) {
+			if (!_lock_initialized)
+				InitializeCriticalSection(section);
+		    EnterCriticalSection( section);
+		}
+		static void __mutex_unlock(CRITICAL_SECTION* section) {
+			if (!_lock_initialized)
+				InitializeCriticalSection(section);
+			LeaveCriticalSection( section);
+		}
+#		define MUTEX_LOCK(x) __mutex_lock(x)
+#		define MUTEX_UNLOCK(x) __mutex_unlock(x)
+#	else
+		static pthread_mutex_t mmapstring_lock = PTHREAD_MUTEX_INITIALIZER;
+#		define MUTEX_LOCK(x) pthread_mutex_lock(x)
+#		define MUTEX_UNLOCK(x) pthread_mutex_unlock(x)
+#	endif
+#else
+#	define MUTEX_LOCK(x) 
+#	define MUTEX_UNLOCK(x)
 #endif
 static chash * mmapstring_hashtable = NULL;
 
@@ -89,18 +122,16 @@ int mmap_string_ref(MMAPString * string)
   chashdatum key;
   chashdatum data;
   
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&mmapstring_lock);
-#endif  
+  MUTEX_LOCK(&mmapstring_lock);
+
   if (mmapstring_hashtable == NULL) {
     mmapstring_hashtable_init();
   }
   ht = mmapstring_hashtable;
   
   if (ht == NULL) {
-#ifdef LIBETPAN_REENTRANT
-    pthread_mutex_unlock(&mmapstring_lock);
-#endif    
+
+	MUTEX_UNLOCK(&mmapstring_lock);
     return -1;
   }
   
@@ -110,9 +141,8 @@ int mmap_string_ref(MMAPString * string)
   data.len = 0;
   
   r = chash_set(mmapstring_hashtable, &key, &data, NULL);
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&mmapstring_lock);
-#endif  
+ 
+  MUTEX_UNLOCK(&mmapstring_lock);
   
   if (r < 0)
     return r;
@@ -128,15 +158,13 @@ int mmap_string_unref(char * str)
   chashdatum data;
   int r;
 
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&mmapstring_lock);
-#endif  
+  MUTEX_LOCK(&mmapstring_lock);
+
   ht = mmapstring_hashtable;
   
   if (ht == NULL) {
-#ifdef LIBETPAN_REENTRANT
-    pthread_mutex_unlock(&mmapstring_lock);
-#endif    
+
+	MUTEX_UNLOCK(&mmapstring_lock);
     return -1;
   }
   
@@ -157,9 +185,7 @@ int mmap_string_unref(char * str)
     }
   }
   
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&mmapstring_lock);
-#endif  
+  MUTEX_UNLOCK(&mmapstring_lock);
 
   if (string != NULL) {
     mmap_string_free(string);
@@ -199,6 +225,8 @@ void mmap_string_set_ceil(size_t ceil)
 /* Strings.
  */
 
+/* SEB */
+#ifndef MMAP_UNAVAILABLE
 static MMAPString * mmap_string_realloc_file(MMAPString * string)
 {
   char * data;
@@ -260,6 +288,7 @@ static MMAPString * mmap_string_realloc_file(MMAPString * string)
   
   return string;
 }
+#endif
 
 static MMAPString * mmap_string_realloc_memory(MMAPString * string)
 {
@@ -374,11 +403,15 @@ mmap_string_free (MMAPString *string)
   if (string == NULL)
     return;
 
+/* SEB */
+#ifndef MMAP_UNAVAILABLE
   if (string->fd != -1) {
     munmap(string->str, string->mmapped_size);
     close(string->fd);
   }
-  else {
+  else
+#endif
+  {
     free (string->str);
   }
   free(string);
