@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: data_message_driver.c,v 1.7 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: data_message_driver.c,v 1.8 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "data_message_driver.h"
@@ -62,7 +62,7 @@ static int fetch_size(mailmessage * msg, size_t * result)
 
 
 static mailmessage_driver local_data_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "data",
   
   /* msg_initialize */ mailmessage_generic_initialize,
