@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: dbdriver.c,v 1.6 2005/06/01 16:04:41 hoa Exp $
+ * $Id: dbdriver.c,v 1.8 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "dbdriver.h"
@@ -87,7 +87,7 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_db_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "db",
 
   /* sess_initialize */ initialize,
@@ -130,6 +130,7 @@ static mailsession_driver local_db_session_driver = {
   /* sess_get_messages_list */ get_messages_list,
   /* sess_get_envelopes_list */ get_envelopes_list,
   /* sess_remove_message */ NULL,
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "db",
@@ -174,6 +175,7 @@ static mailsession_driver local_db_session_driver = {
 
   .sess_get_message = get_message,
   .sess_get_message_by_uid = get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
