@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: dbdriver_message.c,v 1.3 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: dbdriver_message.c,v 1.4 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "dbdriver_message.h"
@@ -63,7 +63,7 @@ static int initialize(mailmessage * msg_info);
 static void check(mailmessage * msg_info);
 
 static mailmessage_driver local_db_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "db",
 
   /* msg_initialize */ initialize,
