@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: dbstorage.c,v 1.3 2005/06/01 12:21:57 smarinier Exp $
+ * $Id: dbstorage.c,v 1.4 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "dbstorage.h"
@@ -53,7 +53,7 @@ db_mailstorage_get_folder_session(struct mailstorage * storage,
 static void db_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver db_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "db",
   /* sto_connect            */ db_mailstorage_connect,
   /* sto_get_folder_session */ db_mailstorage_get_folder_session,
