@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver.c,v 1.48 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: imapdriver.c,v 1.51 2006/02/15 17:57:14 colinleroy Exp $
  */
 
 #include "imapdriver.h"
@@ -126,8 +126,16 @@ static int imapdriver_get_message_by_uid(mailsession * session,
     const char * uid,
     mailmessage ** result);
 
+static int imapdriver_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm);
+
 static mailsession_driver local_imap_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "imap",
 
   /* sess_initialize */ imapdriver_initialize,
@@ -173,6 +181,7 @@ static mailsession_driver local_imap_session_driver = {
 #if 0
   /* sess_search_messages */ imapdriver_search_messages,
 #endif
+  /* sess_login_sasl */ imapdriver_login_sasl,
   
 #else
   .sess_name = "imap",
@@ -220,6 +229,7 @@ static mailsession_driver local_imap_session_driver = {
   
   .sess_get_message = imapdriver_get_message,
   .sess_get_message_by_uid = imapdriver_get_message_by_uid,
+  .sess_login_sasl = imapdriver_login_sasl,
 #endif
 };
 
@@ -1203,7 +1213,7 @@ static int imapdriver_starttls(mailsession * session)
   if (fd == -1)
     return MAIL_ERROR_STREAM;
   
-  new_low = mailstream_low_ssl_open(fd);
+  new_low = mailstream_low_tls_open(fd);
   if (new_low == NULL)
     return MAIL_ERROR_STREAM;
 
@@ -1273,3 +1283,20 @@ static int imapdriver_get_message_by_uid(mailsession * session,
 
   return imapdriver_get_message(session, num, result);
 }
+
+static int imapdriver_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+  int r;
+
+  r = mailimap_authenticate(get_imap_session(session),
+      auth_type, server_fqdn, local_ip_port, remote_ip_port,
+      login, auth_name, password, realm);
+  
+  return imap_error_to_mail_error(r);
+}
