@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_cached.c,v 1.47 2005/06/01 16:04:41 hoa Exp $
+ * $Id: imapdriver_cached.c,v 1.49 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "imapdriver_cached.h"
@@ -136,8 +136,16 @@ static int imapdriver_cached_get_message_by_uid(mailsession * session,
     const char * uid,
     mailmessage ** result);
 
+static int imapdriver_cached_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm);
+
 static mailsession_driver local_imap_cached_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "imap-cached",
 
   /* sess_initialize */ imapdriver_cached_initialize,
@@ -183,6 +191,7 @@ static mailsession_driver local_imap_cached_session_driver = {
 #if 0
   /* sess_search_messages */ imapdriver_cached_search_messages,
 #endif
+  /* sess_cached_login_sasl */ imapdriver_cached_login_sasl,
 
 #else
   .sess_name = "imap-cached",
@@ -230,6 +239,7 @@ static mailsession_driver local_imap_cached_session_driver = {
 
   .sess_get_message = imapdriver_cached_get_message,
   .sess_get_message_by_uid = imapdriver_cached_get_message_by_uid,
+  .sess_login_sasl = imapdriver_cached_login_sasl,
 #endif
 };
 
@@ -1422,3 +1432,19 @@ static int imapdriver_cached_get_message_by_uid(mailsession * session,
 
   return imapdriver_cached_get_message(session, num, result);
 }
+
+static int imapdriver_cached_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+  return mailsession_login_sasl(get_ancestor(session), auth_type,
+      server_fqdn,
+      local_ip_port,
+      remote_ip_port,
+      login, auth_name,
+      password, realm);
+}
