@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_cached_message.c,v 1.22 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: imapdriver_cached_message.c,v 1.23 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "imapdriver_cached_message.h"
@@ -102,7 +102,7 @@ static int imap_get_flags(mailmessage * msg_info,
 			  struct mail_flags ** result);
 
 static mailmessage_driver local_imap_cached_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "imap-cached",
 
   /* msg_initialize */ imap_initialize,
