@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_message.c,v 1.21 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: imapdriver_message.c,v 1.22 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "imapdriver_message.h"
@@ -97,7 +97,7 @@ static void imap_flush(mailmessage * msg_info);
 static void imap_check(mailmessage * msg_info);
 
 static mailmessage_driver local_imap_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "imap",
   
   /* msg_initialize */ imap_initialize,
