@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapstorage.c,v 1.12 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: imapstorage.c,v 1.14 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "imapstorage.h"
@@ -56,7 +56,7 @@ imap_mailstorage_get_folder_session(struct mailstorage * storage,
 static void imap_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver imap_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "imap",
   /* sto_connect            */ imap_mailstorage_connect,
   /* sto_get_folder_session */ imap_mailstorage_get_folder_session,
@@ -78,6 +78,43 @@ int imap_mailstorage_init(struct mailstorage * storage,
     int imap_cached, char * imap_cache_directory)
 {
   struct imap_mailstorage * imap_storage;
+  int r;
+  
+  r = imap_mailstorage_init_sasl(storage,
+      imap_servername, imap_port,
+      imap_command,
+      imap_connection_type,
+      NULL,
+      NULL,
+      NULL, NULL,
+      imap_login, imap_login,
+      imap_password, NULL,
+      imap_cached, imap_cache_directory);
+  
+  if (r == MAIL_NO_ERROR) {
+    imap_storage = storage->sto_data;
+    imap_storage->imap_auth_type = imap_auth_type;
+    imap_storage->imap_login = imap_storage->imap_sasl.sasl_login;
+    imap_storage->imap_password = imap_storage->imap_sasl.sasl_password;
+  }
+  
+  return r;
+}
+
+LIBETPAN_EXPORT
+int imap_mailstorage_init_sasl(struct mailstorage * storage,
+    char * imap_servername, uint16_t imap_port,
+    char * imap_command,
+    int imap_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int imap_cached, char * imap_cache_directory)
+{
+  struct imap_mailstorage * imap_storage;
 
   imap_storage = malloc(sizeof(* imap_storage));
   if (imap_storage == NULL)
@@ -117,30 +154,80 @@ int imap_mailstorage_init(struct mailstorage * storage,
   else
     imap_storage->imap_command = NULL;
   
-  imap_storage->imap_auth_type = imap_auth_type;
+  imap_storage->imap_auth_type = IMAP_AUTH_TYPE_PLAIN;
   
-  if (imap_login != NULL) {
-    imap_storage->imap_login = strdup(imap_login);
-    if (imap_storage->imap_login == NULL)
+  imap_storage->imap_sasl.sasl_enabled = (auth_type != NULL);
+  
+  if (auth_type != NULL) {
+    imap_storage->imap_sasl.sasl_auth_type = strdup(auth_type);
+    if (imap_storage->imap_sasl.sasl_auth_type == NULL)
       goto free_command;
   }
   else
-    imap_storage->imap_login = NULL;
+    imap_storage->imap_sasl.sasl_auth_type = NULL;
+  
+  if (server_fqdn != NULL) {
+    imap_storage->imap_sasl.sasl_server_fqdn = strdup(server_fqdn);
+    if (imap_storage->imap_sasl.sasl_server_fqdn == NULL)
+      goto free_auth_type;
+  }
+  else
+    imap_storage->imap_sasl.sasl_server_fqdn = NULL;
+  
+  if (local_ip_port != NULL) {
+    imap_storage->imap_sasl.sasl_local_ip_port = strdup(local_ip_port);
+    if (imap_storage->imap_sasl.sasl_local_ip_port == NULL)
+      goto free_server_fqdn;
+  }
+  else
+    imap_storage->imap_sasl.sasl_local_ip_port = NULL;
+  
+  if (remote_ip_port != NULL) {
+    imap_storage->imap_sasl.sasl_remote_ip_port = strdup(remote_ip_port);
+    if (imap_storage->imap_sasl.sasl_remote_ip_port == NULL)
+      goto free_local_ip_port;
+  }
+  else
+    imap_storage->imap_sasl.sasl_remote_ip_port = NULL;
+  
+  if (login != NULL) {
+    imap_storage->imap_sasl.sasl_login = strdup(login);
+    if (imap_storage->imap_sasl.sasl_login == NULL)
+      goto free_remote_ip_port;
+  }
+  else
+    imap_storage->imap_sasl.sasl_login = NULL;
 
-  if (imap_password != NULL) {
-    imap_storage->imap_password = strdup(imap_password);
-    if (imap_storage->imap_password == NULL)
+  if (auth_name != NULL) {
+    imap_storage->imap_sasl.sasl_auth_name = strdup(auth_name);
+    if (imap_storage->imap_sasl.sasl_auth_name == NULL)
       goto free_login;
   }
   else
-    imap_storage->imap_password = NULL;
+    imap_storage->imap_sasl.sasl_auth_name = NULL;
+
+  if (password != NULL) {
+    imap_storage->imap_sasl.sasl_password = strdup(password);
+    if (imap_storage->imap_sasl.sasl_password == NULL)
+      goto free_auth_name;
+  }
+  else
+    imap_storage->imap_sasl.sasl_password = NULL;
+
+  if (realm != NULL) {
+    imap_storage->imap_sasl.sasl_realm = strdup(realm);
+    if (imap_storage->imap_sasl.sasl_realm == NULL)
+      goto free_password;
+  }
+  else
+    imap_storage->imap_sasl.sasl_realm = NULL;
 
   imap_storage->imap_cached = imap_cached;
 
   if (imap_cached && (imap_cache_directory != NULL)) {
     imap_storage->imap_cache_directory = strdup(imap_cache_directory);
     if (imap_storage->imap_cache_directory == NULL)
-      goto free_password;
+      goto free_realm;
   }
   else {
     imap_storage->imap_cached = FALSE;
@@ -152,10 +239,22 @@ int imap_mailstorage_init(struct mailstorage * storage,
 
   return MAIL_NO_ERROR;
 
+ free_realm:
+  free(imap_storage->imap_sasl.sasl_realm);
  free_password:
-  free(imap_storage->imap_password);
+  free(imap_storage->imap_sasl.sasl_password);
+ free_auth_name:
+  free(imap_storage->imap_sasl.sasl_auth_name);
  free_login:
-  free(imap_storage->imap_login);
+  free(imap_storage->imap_sasl.sasl_login);
+ free_remote_ip_port:
+  free(imap_storage->imap_sasl.sasl_remote_ip_port);
+ free_local_ip_port:
+  free(imap_storage->imap_sasl.sasl_local_ip_port);
+ free_server_fqdn:
+  free(imap_storage->imap_sasl.sasl_server_fqdn);
+ free_auth_type:
+  free(imap_storage->imap_sasl.sasl_auth_type);
  free_command:
   free(imap_storage->imap_command);
  free_servername:
@@ -174,10 +273,16 @@ static void imap_mailstorage_uninitialize(struct mailstorage * storage)
 
   if (imap_storage->imap_cache_directory != NULL)
     free(imap_storage->imap_cache_directory);
-  if (imap_storage->imap_password != NULL)
-    free(imap_storage->imap_password);
-  if (imap_storage->imap_login != NULL)
-    free(imap_storage->imap_login);
+  
+  free(imap_storage->imap_sasl.sasl_realm);
+  free(imap_storage->imap_sasl.sasl_password);
+  free(imap_storage->imap_sasl.sasl_auth_name);
+  free(imap_storage->imap_sasl.sasl_login);
+  free(imap_storage->imap_sasl.sasl_remote_ip_port);
+  free(imap_storage->imap_sasl.sasl_local_ip_port);
+  free(imap_storage->imap_sasl.sasl_server_fqdn);
+  free(imap_storage->imap_sasl.sasl_auth_type);
+  
   if (imap_storage->imap_command != NULL)
     free(imap_storage->imap_command);
   free(imap_storage->imap_servername);
@@ -201,7 +306,7 @@ static int imap_connect(struct mailstorage * storage,
     driver = imap_cached_session_driver;
   else
     driver = imap_session_driver;
-
+  
   r = mailstorage_generic_connect(driver,
       imap_storage->imap_servername,
       imap_storage->imap_port,
@@ -221,10 +326,23 @@ static int imap_connect(struct mailstorage * storage,
     goto err;
   }
 
-  r = mailstorage_generic_auth(session, r,
-      imap_storage->imap_connection_type,
-      imap_storage->imap_login,
-      imap_storage->imap_password);
+  if (imap_storage->imap_sasl.sasl_enabled) {
+    r = mailstorage_generic_auth_sasl(session, r,
+        imap_storage->imap_sasl.sasl_auth_type,
+        imap_storage->imap_sasl.sasl_server_fqdn,
+        imap_storage->imap_sasl.sasl_local_ip_port,
+        imap_storage->imap_sasl.sasl_remote_ip_port,
+        imap_storage->imap_sasl.sasl_login,
+        imap_storage->imap_sasl.sasl_auth_name,
+        imap_storage->imap_sasl.sasl_password,
+        imap_storage->imap_sasl.sasl_realm);
+  }
+  else {
+    r = mailstorage_generic_auth(session, r,
+        imap_storage->imap_auth_type,
+        imap_storage->imap_sasl.sasl_login,
+        imap_storage->imap_sasl.sasl_password);
+  }
   if (r != MAIL_NO_ERROR) {
     res = r;
     goto free;
