@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapstorage.h,v 1.10 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: imapstorage.h,v 1.11 2005/08/15 11:08:40 hoa Exp $
  */
 
 #ifndef IMAPSTORAGE_H
@@ -84,6 +84,19 @@ int imap_mailstorage_init(struct mailstorage * storage,
     char * imap_login, char * imap_password,
     int imap_cached, char * imap_cache_directory);
 
+LIBETPAN_EXPORT
+int imap_mailstorage_init_sasl(struct mailstorage * storage,
+    char * imap_servername, uint16_t imap_port,
+    char * imap_command,
+    int imap_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int imap_cached, char * imap_cache_directory);
+
 #ifdef __cplusplus
 }
 #endif
