@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildirdriver.c,v 1.10 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: maildirdriver.c,v 1.12 2005/08/15 11:08:40 hoa Exp $
  */
 
 
@@ -105,7 +105,7 @@ static int get_message_by_uid(mailsession * session,
 
 static mailsession_driver local_maildir_session_driver = {
 
-#ifdef _MSC_VER 
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
 	
    /* sess_name */ "maildir",
 
@@ -152,6 +152,7 @@ static mailsession_driver local_maildir_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "maildir",
@@ -199,6 +200,7 @@ static mailsession_driver local_maildir_session_driver = {
 
   .sess_get_message = NULL,
   .sess_get_message_by_uid = get_message_by_uid,
+  .sess_login_sasl = NULL,
 
 #endif
 };
