@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildirdriver_cached.c,v 1.12 2005/06/01 16:04:41 hoa Exp $
+ * $Id: maildirdriver_cached.c,v 1.14 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "maildirdriver.h"
@@ -106,7 +106,7 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_maildir_cached_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
    /* sess_name */ "maildir-cached",
 
   /* sess_initialize */ initialize,
@@ -152,6 +152,7 @@ static mailsession_driver local_maildir_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "maildir-cached",
@@ -199,6 +200,7 @@ static mailsession_driver local_maildir_cached_session_driver = {
 
   .sess_get_message = get_message,
   .sess_get_message_by_uid = get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
