@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildirstorage.c,v 1.6 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: maildirstorage.c,v 1.7 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "maildirstorage.h"
@@ -54,7 +54,7 @@ maildir_mailstorage_get_folder_session(struct mailstorage * storage,
 static void maildir_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver maildir_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "maildir",
   /* sto_connect            */ maildir_mailstorage_connect,
   /* sto_get_folder_session */ maildir_mailstorage_get_folder_session,
