@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxdriver.c,v 1.38 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: mboxdriver.c,v 1.40 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "mboxdriver.h"
@@ -101,7 +101,7 @@ static int mboxdriver_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mbox_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "mbox",
 
   /* sess_initialize */ mboxdriver_initialize,
@@ -148,6 +148,7 @@ static mailsession_driver local_mbox_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "mbox",
@@ -195,6 +196,7 @@ static mailsession_driver local_mbox_session_driver = {
 
   .sess_get_message = mboxdriver_get_message,
   .sess_get_message_by_uid = mboxdriver_get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
