@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxdriver_cached.c,v 1.48 2005/06/19 21:02:07 hoa Exp $
+ * $Id: mboxdriver_cached.c,v 1.50 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "mboxdriver_cached.h"
@@ -112,7 +112,7 @@ static int mboxdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mbox_cached_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "mbox-cached",
 
   /* sess_initialize */ mboxdriver_cached_initialize,
@@ -159,6 +159,7 @@ static mailsession_driver local_mbox_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "mbox-cached",
@@ -207,6 +208,7 @@ static mailsession_driver local_mbox_cached_session_driver = {
 
   .sess_get_message = mboxdriver_cached_get_message,
   .sess_get_message_by_uid = mboxdriver_cached_get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
