@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxdriver_cached_message.c,v 1.22 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: mboxdriver_cached_message.c,v 1.23 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mboxdriver_cached_message.h"
@@ -78,7 +78,7 @@ static int mbox_fetch_header(mailmessage * msg_info,
 			     size_t * result_len);
 
 static mailmessage_driver local_mbox_cached_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "mbox-cached",
 
   /* msg_initialize */ mbox_initialize,
