@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxdriver_message.c,v 1.16 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: mboxdriver_message.c,v 1.17 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mboxdriver_message.h"
@@ -66,7 +66,7 @@ static int mbox_fetch_header(mailmessage * msg_info,
 			     size_t * result_len);
 
 static mailmessage_driver local_mbox_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "mbox",
 
   /* msg_initialize */ mbox_initialize,
