@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mboxstorage.c,v 1.9 2005/06/01 12:21:58 smarinier Exp $
+ * $Id: mboxstorage.c,v 1.10 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mboxstorage.h"
@@ -53,7 +53,7 @@ mbox_mailstorage_get_folder_session(struct mailstorage * storage,
 static void mbox_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver mbox_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "mbox",
   /* sto_connect            */ mbox_mailstorage_connect,
   /* sto_get_folder_session */ mbox_mailstorage_get_folder_session,
