@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhdriver.c,v 1.29 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: mhdriver.c,v 1.31 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "mhdriver.h"
@@ -112,7 +112,7 @@ static int mhdriver_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "mh",
 
   /* sess_initialize */ mhdriver_initialize,
@@ -158,6 +158,7 @@ static mailsession_driver local_mh_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "mh",
@@ -205,6 +206,7 @@ static mailsession_driver local_mh_session_driver = {
 
   .sess_get_message = mhdriver_get_message,
   .sess_get_message_by_uid = mhdriver_get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
