@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhdriver_cached.c,v 1.41 2005/06/01 16:04:43 hoa Exp $
+ * $Id: mhdriver_cached.c,v 1.43 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "mhdriver_cached.h"
@@ -139,7 +139,7 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_cached_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "mh-cached",
 
   /* sess_initialize */ mhdriver_cached_initialize,
@@ -185,6 +185,7 @@ static mailsession_driver local_mh_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "mh-cached",
@@ -232,6 +233,7 @@ static mailsession_driver local_mh_cached_session_driver = {
 
   .sess_get_message = mhdriver_cached_get_message,
   .sess_get_message_by_uid = mhdriver_cached_get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
