@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhdriver_message.c,v 1.19 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: mhdriver_message.c,v 1.20 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mhdriver_message.h"
@@ -66,7 +66,7 @@ static int mh_fetch_header(mailmessage * msg_info,
 			   size_t * result_len);
 
 static mailmessage_driver local_mh_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "mh",
 
   /* msg_initialize */ mh_initialize,
