@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhstorage.c,v 1.9 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: mhstorage.c,v 1.10 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mhstorage.h"
@@ -50,7 +50,7 @@ static int mh_mailstorage_get_folder_session(struct mailstorage * storage,
 static void mh_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver mh_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "mh",
   /* sto_connect            */ mh_mailstorage_connect,
   /* sto_get_folder_session */ mh_mailstorage_get_folder_session,
