@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mime_message_driver.c,v 1.9 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: mime_message_driver.c,v 1.10 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "mime_message_driver.h"
@@ -890,7 +890,7 @@ static int fetch_size(mailmessage * msg_info,
 
 
 static mailmessage_driver local_mime_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "mime",
   
   /* msg_initialize */ initialize,
