@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver.c,v 1.46 2005/06/01 16:04:43 hoa Exp $
+ * $Id: nntpdriver.c,v 1.48 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "nntpdriver.h"
@@ -100,7 +100,7 @@ static int nntpdriver_get_message_by_uid(mailsession * session,
 static int nntpdriver_noop(mailsession * session);
 
 static mailsession_driver local_nntp_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "nntp",
 
   /* sess_initialize */ nntpdriver_initialize,
@@ -146,6 +146,7 @@ static mailsession_driver local_nntp_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "nntp",
@@ -193,6 +194,7 @@ static mailsession_driver local_nntp_session_driver = {
 
   .sess_get_message = nntpdriver_get_message,
   .sess_get_message_by_uid = nntpdriver_get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
