@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver_cached.c,v 1.48 2005/06/01 20:23:15 hoa Exp $
+ * $Id: nntpdriver_cached.c,v 1.50 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "nntpdriver_cached.h"
@@ -140,7 +140,7 @@ static int nntpdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_nntp_cached_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "nntp-cached",
 
   /* sess_initialize */ nntpdriver_cached_initialize,
@@ -186,6 +186,7 @@ static mailsession_driver local_nntp_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
+  /* sess_login_sasl */ NULL,
 
 #else
   .sess_name = "nntp-cached",
@@ -233,6 +234,7 @@ static mailsession_driver local_nntp_cached_session_driver = {
 
   .sess_get_message = nntpdriver_cached_get_message,
   .sess_get_message_by_uid = nntpdriver_cached_get_message_by_uid,
+  .sess_login_sasl = NULL,
 #endif
 };
 
