@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver_cached_message.c,v 1.16 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: nntpdriver_cached_message.c,v 1.17 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "nntpdriver_cached_message.h"
@@ -71,7 +71,7 @@ static int nntp_get_flags(mailmessage * msg_info,
 			  struct mail_flags ** result);
 
 static mailmessage_driver local_nntp_cached_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "nntp-cached",
 
   /* msg_initialize */ nntp_initialize,
