@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver_message.c,v 1.12 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: nntpdriver_message.c,v 1.13 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "nntpdriver_message.h"
@@ -56,7 +56,7 @@ static int nntp_fetch_size(mailmessage * msg_info,
 			   size_t * result);
 
 static mailmessage_driver local_nntp_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
 
   /* msg_name */ "nntp",
 
