@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpstorage.c,v 1.12 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: nntpstorage.c,v 1.13 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "nntpstorage.h"
@@ -55,7 +55,7 @@ static int nntp_mailstorage_get_folder_session(struct mailstorage * storage,
 static void nntp_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver nntp_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "nntp",
   /* sto_connect            */ nntp_mailstorage_connect,
   /* sto_get_folder_session */ nntp_mailstorage_get_folder_session,
