@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver.c,v 1.31 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: pop3driver.c,v 1.35 2006/02/15 17:57:14 colinleroy Exp $
  */
 
 #include "pop3driver.h"
@@ -76,8 +76,16 @@ static int pop3driver_get_messages_list(mailsession * session,
 static int pop3driver_get_message(mailsession * session,
 				  uint32_t num, mailmessage ** result);
 
+static int pop3driver_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm);
+
 static mailsession_driver local_pop3_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
 	
   /* sess_name */ "pop3",
 
@@ -124,7 +132,8 @@ static mailsession_driver local_pop3_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-
+  /* sess_login_sasl */ pop3driver_login_sasl,
+  
 #else
   .sess_name = "pop3",
 
@@ -171,6 +180,7 @@ static mailsession_driver local_pop3_session_driver = {
 
   .sess_get_message = pop3driver_get_message,
   .sess_get_message_by_uid = NULL,
+  .sess_login_sasl = pop3driver_login_sasl,
 #endif
 };
 
@@ -264,7 +274,7 @@ static int pop3driver_starttls(mailsession * session)
   if (fd == -1)
     return MAIL_ERROR_STREAM;
   
-  new_low = mailstream_low_ssl_open(fd);
+  new_low = mailstream_low_tls_open(fd);
   if (new_low == NULL)
     return MAIL_ERROR_STREAM;
   mailstream_low_free(low);
@@ -436,3 +446,20 @@ static int pop3driver_get_message(mailsession * session,
 
   return MAIL_NO_ERROR;
 }
+
+static int pop3driver_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+  int r;
+
+  r = mailpop3_auth(get_pop3_session(session),
+      auth_type, server_fqdn, local_ip_port, remote_ip_port,
+      login, auth_name, password, realm);
+  
+  return pop3driver_pop3_error_to_mail_error(r);
+}
