@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_cached.c,v 1.42 2005/06/01 12:21:59 smarinier Exp $
+ * $Id: pop3driver_cached.c,v 1.44 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "pop3driver_cached.h"
@@ -115,8 +115,16 @@ static int pop3driver_cached_get_message(mailsession * session,
 static int pop3driver_cached_get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
+static int pop3driver_cached_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm);
+
 static mailsession_driver local_pop3_cached_session_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "pop3-cached",
 
   /* sess_initialize */ pop3driver_cached_initialize,
@@ -162,7 +170,8 @@ static mailsession_driver local_pop3_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-
+  /* sess_login_sasl */ pop3driver_cached_login_sasl,
+  
 #else
   .sess_name = "pop3-cached",
 
@@ -209,6 +218,7 @@ static mailsession_driver local_pop3_cached_session_driver = {
 
   .sess_get_message = pop3driver_cached_get_message,
   .sess_get_message_by_uid = pop3driver_cached_get_message_by_uid,
+  .sess_login_sasl = pop3driver_cached_login_sasl,
 #endif
 };
 
@@ -948,3 +958,19 @@ static int pop3driver_cached_get_message_by_uid(mailsession * session,
   
   return pop3driver_cached_get_message(session, msg_info->msg_index, result);
 }
+
+static int pop3driver_cached_login_sasl(mailsession * session,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+  return mailsession_login_sasl(get_ancestor(session), auth_type,
+      server_fqdn,
+      local_ip_port,
+      remote_ip_port,
+      login, auth_name,
+      password, realm);
+}
