@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_cached_message.c,v 1.17 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: pop3driver_cached_message.c,v 1.18 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "pop3driver_cached_message.h"
@@ -71,7 +71,7 @@ static int pop3_get_flags(mailmessage * msg_info,
 static void pop3_uninitialize(mailmessage * msg_info);
 
 static mailmessage_driver local_pop3_cached_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "pop3-cached",
 
   /* msg_initialize */ pop3_initialize,
