@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_message.c,v 1.11 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: pop3driver_message.c,v 1.12 2005/08/13 14:59:42 hoa Exp $
  */
 
 #include "pop3driver_message.h"
@@ -56,7 +56,7 @@ static int pop3_fetch_size(mailmessage * msg_info,
 			   size_t * result);
 
 static mailmessage_driver local_pop3_message_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* msg_name */ "pop3",
 
   /* msg_initialize */ pop3_initialize,
