@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3storage.c,v 1.12 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: pop3storage.c,v 1.14 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "pop3storage.h"
@@ -53,7 +53,7 @@ static int pop3_mailstorage_get_folder_session(struct mailstorage * storage,
 static void pop3_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver pop3_mailstorage_driver = {
-#ifdef _MSC_VER
+#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sto_name               */ "pop3",
   /* sto_connect            */ pop3_mailstorage_connect,
   /* sto_get_folder_session */ pop3_mailstorage_get_folder_session,
@@ -75,6 +75,45 @@ int pop3_mailstorage_init(struct mailstorage * storage,
     int pop3_cached, char * pop3_cache_directory, char * pop3_flags_directory)
 {
   struct pop3_mailstorage * pop3_storage;
+  int r;
+  
+  r =  pop3_mailstorage_init_sasl(storage,
+      pop3_servername, pop3_port,
+      pop3_command,
+      pop3_connection_type,
+      NULL,
+      NULL,
+      NULL, NULL,
+      pop3_login, pop3_login,
+      pop3_password, NULL,
+      pop3_cached, pop3_cache_directory,
+      pop3_flags_directory);
+  
+  if (r == MAIL_NO_ERROR) {
+    pop3_storage = storage->sto_data;
+    pop3_storage->pop3_auth_type = pop3_auth_type;
+    pop3_storage->pop3_login = pop3_storage->pop3_sasl.sasl_login;
+    pop3_storage->pop3_password = pop3_storage->pop3_sasl.sasl_password;
+  }
+  
+  return r;
+}
+
+LIBETPAN_EXPORT
+int pop3_mailstorage_init_sasl(struct mailstorage * storage,
+    char * pop3_servername, uint16_t pop3_port,
+    char * pop3_command,
+    int pop3_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int pop3_cached, char * pop3_cache_directory,
+    char * pop3_flags_directory)
+{
+  struct pop3_mailstorage * pop3_storage;
 
   pop3_storage = malloc(sizeof(* pop3_storage));
   if (pop3_storage == NULL)
@@ -114,31 +153,81 @@ int pop3_mailstorage_init(struct mailstorage * storage,
   else
     pop3_storage->pop3_command = NULL;
   
-  pop3_storage->pop3_auth_type = pop3_auth_type;
+  pop3_storage->pop3_auth_type = POP3_AUTH_TYPE_PLAIN;
   
-  if (pop3_login != NULL) {
-    pop3_storage->pop3_login = strdup(pop3_login);
-    if (pop3_storage->pop3_login == NULL)
+  pop3_storage->pop3_sasl.sasl_enabled = (auth_type != NULL);
+  
+  if (auth_type != NULL) {
+    pop3_storage->pop3_sasl.sasl_auth_type = strdup(auth_type);
+    if (pop3_storage->pop3_sasl.sasl_auth_type == NULL)
       goto free_command;
   }
   else
-    pop3_storage->pop3_login = NULL;
+    pop3_storage->pop3_sasl.sasl_auth_type = NULL;
   
-  if (pop3_password != NULL) {
-    pop3_storage->pop3_password = strdup(pop3_password);
-    if (pop3_storage->pop3_password == NULL)
+  if (server_fqdn != NULL) {
+    pop3_storage->pop3_sasl.sasl_server_fqdn = strdup(server_fqdn);
+    if (pop3_storage->pop3_sasl.sasl_server_fqdn == NULL)
+      goto free_auth_type;
+  }
+  else
+    pop3_storage->pop3_sasl.sasl_server_fqdn = NULL;
+  
+  if (local_ip_port != NULL) {
+    pop3_storage->pop3_sasl.sasl_local_ip_port = strdup(local_ip_port);
+    if (pop3_storage->pop3_sasl.sasl_local_ip_port == NULL)
+      goto free_server_fqdn;
+  }
+  else
+    pop3_storage->pop3_sasl.sasl_local_ip_port = NULL;
+  
+  if (remote_ip_port != NULL) {
+    pop3_storage->pop3_sasl.sasl_remote_ip_port = strdup(remote_ip_port);
+    if (pop3_storage->pop3_sasl.sasl_remote_ip_port == NULL)
+      goto free_local_ip_port;
+  }
+  else
+    pop3_storage->pop3_sasl.sasl_remote_ip_port = NULL;
+  
+  if (login != NULL) {
+    pop3_storage->pop3_sasl.sasl_login = strdup(login);
+    if (pop3_storage->pop3_sasl.sasl_login == NULL)
+      goto free_remote_ip_port;
+  }
+  else
+    pop3_storage->pop3_sasl.sasl_login = NULL;
+
+  if (auth_name != NULL) {
+    pop3_storage->pop3_sasl.sasl_auth_name = strdup(auth_name);
+    if (pop3_storage->pop3_sasl.sasl_auth_name == NULL)
       goto free_login;
   }
   else
-    pop3_storage->pop3_password = NULL;
+    pop3_storage->pop3_sasl.sasl_auth_name = NULL;
 
+  if (password != NULL) {
+    pop3_storage->pop3_sasl.sasl_password = strdup(password);
+    if (pop3_storage->pop3_sasl.sasl_password == NULL)
+      goto free_auth_name;
+  }
+  else
+    pop3_storage->pop3_sasl.sasl_password = NULL;
+
+  if (realm != NULL) {
+    pop3_storage->pop3_sasl.sasl_realm = strdup(realm);
+    if (pop3_storage->pop3_sasl.sasl_realm == NULL)
+      goto free_password;
+  }
+  else
+    pop3_storage->pop3_sasl.sasl_realm = NULL;
+  
   pop3_storage->pop3_cached = pop3_cached;
 
   if (pop3_cached && (pop3_cache_directory != NULL) &&
       (pop3_flags_directory != NULL)) {
     pop3_storage->pop3_cache_directory = strdup(pop3_cache_directory);
     if (pop3_storage->pop3_cache_directory == NULL)
-      goto free_password;
+      goto free_realm;
     pop3_storage->pop3_flags_directory = strdup(pop3_flags_directory);
     if (pop3_storage->pop3_flags_directory == NULL)
       goto free_cache_directory;
@@ -156,12 +245,22 @@ int pop3_mailstorage_init(struct mailstorage * storage,
 
  free_cache_directory:
   free(pop3_storage->pop3_cache_directory);
+ free_realm:
+  free(pop3_storage->pop3_sasl.sasl_realm);
  free_password:
-  if (pop3_storage->pop3_password != NULL)
-    free(pop3_storage->pop3_password);
+  free(pop3_storage->pop3_sasl.sasl_password);
+ free_auth_name:
+  free(pop3_storage->pop3_sasl.sasl_auth_name);
  free_login:
-  if (pop3_storage->pop3_login != NULL)
-    free(pop3_storage->pop3_login);
+  free(pop3_storage->pop3_sasl.sasl_login);
+ free_remote_ip_port:
+  free(pop3_storage->pop3_sasl.sasl_remote_ip_port);
+ free_local_ip_port:
+  free(pop3_storage->pop3_sasl.sasl_local_ip_port);
+ free_server_fqdn:
+  free(pop3_storage->pop3_sasl.sasl_server_fqdn);
+ free_auth_type:
+  free(pop3_storage->pop3_sasl.sasl_auth_type);
  free_command:
   if (pop3_storage->pop3_command != NULL)
     free(pop3_storage->pop3_command);
@@ -184,10 +283,16 @@ static void pop3_mailstorage_uninitialize(struct mailstorage * storage)
     free(pop3_storage->pop3_flags_directory);
   if (pop3_storage->pop3_cache_directory != NULL)
     free(pop3_storage->pop3_cache_directory);
-  if (pop3_storage->pop3_password != NULL)
-    free(pop3_storage->pop3_password);
-  if (pop3_storage->pop3_login != NULL)
-    free(pop3_storage->pop3_login);
+
+  free(pop3_storage->pop3_sasl.sasl_realm);
+  free(pop3_storage->pop3_sasl.sasl_password);
+  free(pop3_storage->pop3_sasl.sasl_auth_name);
+  free(pop3_storage->pop3_sasl.sasl_login);
+  free(pop3_storage->pop3_sasl.sasl_remote_ip_port);
+  free(pop3_storage->pop3_sasl.sasl_local_ip_port);
+  free(pop3_storage->pop3_sasl.sasl_server_fqdn);
+  free(pop3_storage->pop3_sasl.sasl_auth_type);
+  
   if (pop3_storage->pop3_command != NULL)
     free(pop3_storage->pop3_command);
   free(pop3_storage->pop3_servername);
@@ -248,10 +353,23 @@ static int pop3_mailstorage_connect(struct mailstorage * storage)
     mailsession_parameters(session, POP3DRIVER_SET_AUTH_TYPE, &auth_type);
   }
 
-  r = mailstorage_generic_auth(session, r,
-      pop3_storage->pop3_auth_type,
-      pop3_storage->pop3_login,
-      pop3_storage->pop3_password);
+  if (pop3_storage->pop3_sasl.sasl_enabled) {
+    r = mailstorage_generic_auth_sasl(session, r,
+        pop3_storage->pop3_sasl.sasl_auth_type,
+        pop3_storage->pop3_sasl.sasl_server_fqdn,
+        pop3_storage->pop3_sasl.sasl_local_ip_port,
+        pop3_storage->pop3_sasl.sasl_remote_ip_port,
+        pop3_storage->pop3_sasl.sasl_login,
+        pop3_storage->pop3_sasl.sasl_auth_name,
+        pop3_storage->pop3_sasl.sasl_password,
+        pop3_storage->pop3_sasl.sasl_realm);
+  }
+  else {
+    r = mailstorage_generic_auth(session, r,
+        pop3_storage->pop3_auth_type,
+        pop3_storage->pop3_sasl.sasl_login,
+        pop3_storage->pop3_sasl.sasl_password);
+  }
   if (r != MAIL_NO_ERROR) {
     if (pop3_storage->pop3_auth_type == POP3_AUTH_TYPE_TRY_APOP) {
       /* try in clear authentication */
