@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3storage.h,v 1.9 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: pop3storage.h,v 1.10 2005/08/15 11:08:40 hoa Exp $
  */
 
 #ifndef POP3STORAGE_H
@@ -89,6 +89,20 @@ int pop3_mailstorage_init(struct mailstorage * storage,
     int pop3_cached, char * pop3_cache_directory,
     char * pop3_flags_directory);
 
+LIBETPAN_EXPORT
+int pop3_mailstorage_init_sasl(struct mailstorage * storage,
+    char * pop3_servername, uint16_t pop3_port,
+    char * pop3_command,
+    int pop3_connection_type,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm,
+    int pop3_cached, char * pop3_cache_directory,
+    char * pop3_flags_directory);
+
 #ifdef __cplusplus
 }
 #endif
