@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver.c,v 1.24 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: maildriver.c,v 1.25 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "maildriver.h"
@@ -416,3 +416,22 @@ int mailsession_get_message_by_uid(mailsession * session,
   
   return session->sess_driver->sess_get_message_by_uid(session, uid, result);
 }
+
+LIBETPAN_EXPORT
+int mailsession_login_sasl(mailsession * session, const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+  if (session->sess_driver->sess_login_sasl == NULL)
+    return MAIL_ERROR_NOT_IMPLEMENTED;
+
+  return session->sess_driver->sess_login_sasl(session, auth_type,
+      server_fqdn,
+      local_ip_port,
+      remote_ip_port,
+      login, auth_name,
+      password, realm);
+}
