@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver.h,v 1.32 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: maildriver.h,v 1.33 2005/08/15 11:08:40 hoa Exp $
  */
 
 #ifndef MAILDRIVER_H
@@ -574,6 +574,32 @@ LIBETPAN_EXPORT
 int mailsession_get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
+
+/*
+  mailsession_login notifies the SASL authentication information
+  to the session
+
+  @param auth_type      type of SASL authentication
+  @param server_fqdn    server full qualified domain name
+  @param local_ip_port  local IP:port (client)
+  @param remote_ip_port remote IP:port (server)
+  @param login          login
+  @param auth_name      authentication name
+  @param password       password
+  @param realm          realm
+
+  @return MAIL_NO_ERROR is returned on success, MAIL_ERROR_XXX is returned
+    on error
+*/
+
+LIBETPAN_EXPORT
+int mailsession_login_sasl(mailsession * session, const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm);
+
 #ifdef __cplusplus
 }
 #endif
