@@ -30,19 +30,29 @@
  */
 
 /*
- * $Id: maildriver_tools.c,v 1.30 2004/11/21 21:53:34 hoa Exp $
+ * $Id: maildriver_tools.c,v 1.32 2005/06/01 20:23:15 hoa Exp $
  */
 
 #include "maildriver_tools.h"
 
 #include "libetpan-config.h"
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
-#include <dirent.h>
-#include <unistd.h>
-
+#ifdef _MSC_VER
+#include "win_etpan.h"
+#else
+#	include <dirent.h>
+#endif
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 #include "maildriver.h"
 #include "mailmessage.h"
 #include "mailstream.h"
@@ -675,7 +685,6 @@ char * maildriver_quote_mailbox(char * mb)
 }
 
 
-
 int maildriver_cache_clean_up(struct mail_cache_db * cache_db_env,
     struct mail_cache_db * cache_db_flags,
     struct mailmessage_list * env_list)
@@ -745,7 +754,6 @@ int maildriver_cache_clean_up(struct mail_cache_db * cache_db_env,
   return res;
 }
 
-
 /*
   maildriver_message_cache_clean_up()
   
