@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildriver_types.h,v 1.42 2005/06/01 12:22:00 smarinier Exp $
+ * $Id: maildriver_types.h,v 1.43 2005/08/15 11:08:40 hoa Exp $
  */
 
 #ifndef MAILDRIVER_TYPES_H
@@ -458,6 +458,8 @@ void mail_search_result_free(struct mail_search_result * search_result);
       STARTTLS.
   - get_message_by_uid() so that the application can remember the message
       by UID and build its own list of messages.
+  - login_sasl() notifies the SASL information to authenticate to the
+      session.
 
   * drivers' specific :
 
@@ -543,6 +545,13 @@ struct mailsession_driver {
       struct mail_search_key * key,
       struct mail_search_result ** result);
 #endif
+  
+  int (* sess_login_sasl)(mailsession * session, const char * auth_type,
+      const char * server_fqdn,
+      const char * local_ip_port,
+      const char * remote_ip_port,
+      const char * login, const char * auth_name,
+      const char * password, const char * realm);
 };
 
 
