@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstorage_tools.c,v 1.15 2005/06/01 12:22:01 smarinier Exp $
+ * $Id: mailstorage_tools.c,v 1.18 2005/08/15 11:08:40 hoa Exp $
  */
 
 #include "mailstorage_tools.h"
@@ -102,10 +102,15 @@ static int tcp_connect(char * server, uint16_t port)
 /* SEB unsupported on Windows */
 #ifndef WIN32
 
+#define ENV_BUFFER_SIZE 512
+
 static void do_exec_command(int fd, const char *command,
     char *servername, uint16_t port)
 {
   int i, maxopen;
+#ifdef SOLARIS
+  char env_buffer[ENV_BUFFER_SIZE];
+#endif
   
   if (fork() > 0) {
     /* Fork again to become a child of init rather than
@@ -113,11 +118,26 @@ static void do_exec_command(int fd, const char *command,
     exit(0);
   }
   
+#ifdef SOLARIS
+  if (servername)
+    snprintf(env_buffer, ENV_BUFFER_SIZE, "ETPANSERVER=%s", servername);
+  else
+    snprintf(env_buffer, ENV_BUFFER_SIZE, "ETPANSERVER=");
+  putenv(env_buffer);
+#else
   if (servername)
     setenv("ETPANSERVER", servername, 1);
   else
     unsetenv("ETPANSERVER");
+#endif
   
+#ifdef SOLARIS
+  if (port)
+    snprintf(env_buffer, ENV_BUFFER_SIZE, "ETPANPORT=%d", port);
+  else
+    snprintf(env_buffer, ENV_BUFFER_SIZE, "ETPANPORT=");
+  putenv(env_buffer);
+#else
   if (port) {
     char porttext[20];
     
@@ -127,6 +147,7 @@ static void do_exec_command(int fd, const char *command,
   else {
     unsetenv("ETPANPORT");
   }
+#endif
   
   /* Not a lot we can do if there's an error other than bail. */
   if (dup2(fd, 0) == -1)
@@ -388,3 +409,51 @@ int mailstorage_generic_auth(mailsession * session,
  err:
   return res;
 }
+
+int mailstorage_generic_auth_sasl(mailsession * session,
+    int connect_result,
+    const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+  int must_auth;
+  int r;
+  int res;
+
+  r = connect_result;
+
+  must_auth = FALSE;
+  switch (r) {
+  case MAIL_NO_ERROR_NON_AUTHENTICATED:
+    must_auth = TRUE;
+    break;
+  case MAIL_NO_ERROR_AUTHENTICATED:
+  case MAIL_NO_ERROR:
+    break;
+  default:
+    res = r;
+    goto err;
+  }
+
+  if (must_auth) {
+    r = mailsession_login_sasl(session, auth_type,
+        server_fqdn,
+        local_ip_port,
+        remote_ip_port,
+        login, auth_name,
+        password, realm);
+    if (r != MAIL_NO_ERROR) {
+      mailsession_logout(session);
+      res = r;
+      goto err;
+    }
+  }
+
+  return MAIL_NO_ERROR;
+
+ err:
+  return res;
+}
