@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailengine.c,v 1.8 2005/06/13 07:24:07 hoa Exp $
+ * $Id: mailengine.c,v 1.10 2005/12/16 02:19:15 hoa Exp $
  */
 
 #include "mailengine.h"
@@ -52,130 +52,6 @@
 #endif
 #include <string.h>
 
-/* ************************************************************* */
-/* Message finder */
-
-#if 0
-struct message_folder_finder {
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_t lock;
-#endif
-  
-  /* msg => folder */
-  chash * message_hash;
-};
-
-static int message_folder_finder_init(struct message_folder_finder * finder)
-{
-  int r;
-  
-#ifdef LIBETPAN_REENTRANT
-  r = pthread_mutex_init(&finder->lock, NULL);
-  if (r != 0)
-    return MAIL_ERROR_MEMORY;
-#endif
-  
-  finder->message_hash = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
-  if (finder->message_hash == NULL)
-    return MAIL_ERROR_MEMORY;
-  
-  return MAIL_NO_ERROR;
-}
-
-static void message_folder_finder_done(struct message_folder_finder * finder)
-{
-  chash_free(finder->message_hash);
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_destroy(&finder->lock);
-#endif
-}
-
-static struct mailfolder *
-message_folder_finder_lookup(struct message_folder_finder * finder,
-    mailmessage * msg)
-{
-  int r;
-  chashdatum key;
-  chashdatum data;
-  struct mailfolder * folder;
-
-  key.data = &msg;
-  key.len = sizeof(msg);
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&finder->lock);
-#endif
-  r = chash_get(finder->message_hash, &key, &data);
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&finder->lock);
-#endif
-  if (r < 0)
-    return NULL;
-  
-  folder = data.data;
-  
-  return folder;
-}
-
-static inline int
-message_folder_finder_store_no_lock(struct message_folder_finder * finder,
-    mailmessage * msg, struct mailfolder * folder)
-{
-  int r;
-  chashdatum key;
-  chashdatum data;
-
-  key.data = &msg;
-  key.len = sizeof(msg);
-  data.data = folder;
-  data.len = 0;
-  r = chash_set(finder->message_hash, &key, &data, NULL);
-  if (r < 0)
-    return MAIL_ERROR_MEMORY;
-  
-  return MAIL_NO_ERROR;
-}
-
-static int
-message_folder_finder_store(struct message_folder_finder * finder,
-    mailmessage * msg, struct mailfolder * folder)
-{
-  int r;
-  
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&finder->lock);
-#endif
-  r = message_folder_finder_store_no_lock(finder, msg, folder);
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&finder->lock);
-#endif  
-  
-  return r;
-}
-
-static inline void
-message_folder_finder_delete_no_lock(struct message_folder_finder * finder,
-    mailmessage * msg)
-{
-  chashdatum key;
-  
-  key.data = &msg;
-  key.len = sizeof(msg);
-  chash_delete(finder->message_hash, &key, NULL);
-}
-
-static void
-message_folder_finder_delete(struct message_folder_finder * finder,
-    mailmessage * msg)
-{
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_lock(&finder->lock);
-#endif  
-  message_folder_finder_delete_no_lock(finder, msg);
-#ifdef LIBETPAN_REENTRANT
-  pthread_mutex_unlock(&finder->lock);
-#endif  
-}
-#endif
 
 /* ************************************************************* */
 /* Message ref info */
@@ -186,7 +62,9 @@ struct message_ref_elt {
   int mime_ref_count;
   struct mailfolder * folder;
   int lost;
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_t lock;
+#endif
 };
 
 static struct message_ref_elt *
@@ -199,9 +77,11 @@ message_ref_elt_new(struct mailfolder * folder, mailmessage * msg)
   if (ref == NULL)
     goto err;
   
+#ifdef LIBETPAN_REENTRANT
   r = pthread_mutex_init(&ref->lock, NULL);
   if (r != 0)
     goto free;
+#endif
   
   ref->msg = msg;
   ref->ref_count = 0;
@@ -219,7 +99,9 @@ message_ref_elt_new(struct mailfolder * folder, mailmessage * msg)
 
 static void message_ref_elt_free(struct message_ref_elt * ref_elt)
 {
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_destroy(&ref_elt->lock);
+#endif
   free(ref_elt);
 }
 
@@ -227,12 +109,16 @@ static inline int message_ref(struct message_ref_elt * ref_elt)
 {
   int count;
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_lock(&ref_elt->lock);
+#endif
   
   ref_elt->ref_count ++;
   count = ref_elt->ref_count;
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_unlock(&ref_elt->lock);
+#endif
   
   return count;
 }
@@ -241,12 +127,16 @@ static inline int message_unref(struct message_ref_elt * ref_elt)
 {
   int count;
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_lock(&ref_elt->lock);
+#endif
   
   ref_elt->ref_count --;
   count = ref_elt->ref_count;
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_unlock(&ref_elt->lock);
+#endif
   
   return count;
 }
@@ -268,10 +158,14 @@ static inline int message_mime_ref(struct mailprivacy * privacy,
   
   message_ref(ref_elt);
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_lock(&ref_elt->lock);
+#endif
   ref_elt->mime_ref_count ++;
   count = ref_elt->mime_ref_count;
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_unlock(&ref_elt->lock);
+#endif
   
   return count;
 }
@@ -283,7 +177,9 @@ static inline int message_mime_unref(struct mailprivacy * privacy,
   
   message_unref(ref_elt);
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_lock(&ref_elt->lock);
+#endif
   ref_elt->mime_ref_count --;
   
   if (ref_elt->mime_ref_count == 0)
@@ -291,7 +187,9 @@ static inline int message_mime_unref(struct mailprivacy * privacy,
   
   count = ref_elt->mime_ref_count;
   
+#ifdef LIBETPAN_REENTRANT
   pthread_mutex_unlock(&ref_elt->lock);
+#endif
   
   return count;
 }
@@ -302,9 +200,6 @@ static inline int message_mime_unref(struct mailprivacy * privacy,
 
 struct folder_ref_info {
   struct mailfolder * folder;
-#if 0
-  struct message_folder_finder * msg_folder_finder;
-#endif
   
   /* msg => msg_ref_info */
   chash * msg_hash;
@@ -326,9 +221,6 @@ folder_ref_info_new(struct mailfolder * folder
     goto err;
   
   ref_info->folder = folder;
-#if 0
-  ref_info->msg_folder_finder = msg_folder_finder;
-#endif
   
   ref_info->msg_hash = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
   if (ref_info->msg_hash == NULL)
@@ -466,16 +358,9 @@ static int folder_message_add(struct folder_ref_info * ref_info,
   struct message_ref_elt * msg_ref;
   int r;
   
-  /*
-  r = message_folder_finder_store(ref_info->msg_folder_finder,
-      msg, ref_info->folder);
-  if (r != MAIL_NO_ERROR)
-    goto err;
-  */
-  
   msg_ref = message_ref_elt_new(ref_info->folder, msg);  
   if (msg_ref == NULL)
-    goto msg_folder_remove;
+    goto err;
   
   key.data = &msg;
   key.len = sizeof(msg);
@@ -505,10 +390,6 @@ static int folder_message_add(struct folder_ref_info * ref_info,
   chash_delete(ref_info->msg_hash, &key, NULL);
  free_msg_ref:
   message_ref_elt_free(msg_ref);
- msg_folder_remove:
-  /*
-  message_folder_finder_delete(ref_info->msg_folder_finder, msg);
-  */
  err:
   return MAIL_ERROR_MEMORY;
 }
@@ -534,10 +415,6 @@ static void folder_message_remove(struct folder_ref_info * ref_info,
   key.len = sizeof(msg);
   
   chash_delete(ref_info->msg_hash, &key, NULL);
-  
-  /*
-  message_folder_finder_delete(ref_info->msg_folder_finder, msg);
-  */
 }
 
 
@@ -727,14 +604,6 @@ static void folder_free_msg_list(struct folder_ref_info * ref_info,
 
 struct storage_ref_info {
   struct mailstorage * storage;
-#if 0
-  struct message_folder_finder * msg_folder_finder;
-#endif
-
-#if 0  
-  /* msg => folder */
-  chash * msg_ref;
-#endif
   
   /* folder => folder_ref_info */
   chash * folder_ref_info;
@@ -751,9 +620,6 @@ storage_ref_info_new(struct mailstorage * storage
     goto err;
   
   ref_info->storage = storage;
-#if 0
-  ref_info->msg_folder_finder = msg_folder_finder;
-#endif
   
   ref_info->folder_ref_info = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
   if (ref_info->folder_ref_info == NULL)
@@ -769,9 +635,6 @@ storage_ref_info_new(struct mailstorage * storage
 
 static void storage_ref_info_free(struct storage_ref_info * ref_info)
 {
-#if 0
-  chash_free(ref_info->msg_ref);
-#endif
   chash_free(ref_info->folder_ref_info);
   free(ref_info);
 }
@@ -1026,8 +889,10 @@ static int storage_folder_connect(struct storage_ref_info * ref_info,
   folder_ref_info = storage_get_folder_ref(ref_info, folder);
   if (folder_ref_info == NULL) {
     folder_ref_info = storage_folder_add_ref(ref_info, folder);
-    if (folder_ref_info == NULL)
-      return MAIL_ERROR_MEMORY;
+    if (folder_ref_info == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto err;
+    }
   }
   
   /* connect folder */
@@ -1043,7 +908,7 @@ static int storage_folder_connect(struct storage_ref_info * ref_info,
   
   if (r != MAIL_NO_ERROR) {
     res = r;
-    goto err;
+    goto remove_ref;
   }
   
   /* test folder connection */
@@ -1065,6 +930,8 @@ static int storage_folder_connect(struct storage_ref_info * ref_info,
   
  disconnect:
   folder_disconnect(ref_info, folder);
+ remove_ref:
+  storage_folder_remove_ref(ref_info, folder);
  err:
   return res;
 }
@@ -1153,10 +1020,6 @@ struct mailengine {
 #endif  
   /* storage => storage_ref_info */
   chash * storage_hash;
-
-#if 0  
-  struct message_folder_finder msg_folder_finder;
-#endif
 };
 
 static struct storage_ref_info *
@@ -1265,12 +1128,6 @@ libetpan_engine_new(struct mailprivacy * privacy)
   
   engine->privacy = privacy;
   
-#if 0
-  r = message_folder_finder_init(&engine->msg_folder_finder);
-  if (r != MAIL_NO_ERROR)
-    goto free;
-#endif
-  
 #ifdef LIBETPAN_REENTRANT
   r = pthread_mutex_init(&engine->storage_hash_lock, NULL);
   if (r != 0)
@@ -1286,10 +1143,6 @@ libetpan_engine_new(struct mailprivacy * privacy)
  destroy_mutex:
 #ifdef LIBETPAN_REENTRANT
   pthread_mutex_destroy(&engine->storage_hash_lock);
-#endif  
-#if 0
- finder_done:
-  message_folder_finder_done(&engine->msg_folder_finder);
 #endif
  free:
   free(engine);
@@ -1303,36 +1156,9 @@ void libetpan_engine_free(struct mailengine * engine)
 #ifdef LIBETPAN_REENTRANT
   pthread_mutex_destroy(&engine->storage_hash_lock);
 #endif  
-#if 0
-  message_folder_finder_done(&engine->msg_folder_finder);
-#endif
   free(engine);
 }
 
-#if 0
-static struct folder_ref_info *
-message_get_folder_ref(struct mailengine * engine,
-    mailmessage * msg)
-{
-  struct mailfolder * folder;
-  struct mailstorage * storage;
-  struct storage_ref_info * storage_ref_info;
-  struct folder_ref_info * folder_ref_info;
-  
-  folder = message_folder_finder_lookup(&engine->msg_folder_finder, msg);
-  if (folder == NULL)
-    storage = NULL;
-  else
-    storage = folder->fld_storage;
-  
-  storage_ref_info = get_storage_ref_info(engine, storage);
-  
-  folder_ref_info = storage_get_folder_ref(storage_ref_info, folder);
-  
-  return folder_ref_info;
-}
-#endif
-
 static struct folder_ref_info *
 message_get_folder_ref(struct mailengine * engine,
     mailmessage * msg)
@@ -1527,9 +1353,6 @@ struct mailfolder *
 libetpan_message_get_folder(struct mailengine * engine,
     mailmessage * msg)
 {
-#if 0
-  return message_folder_finder_lookup(&engine->msg_folder_finder, msg);
-#endif
   return msg->msg_folder;
 }
 
@@ -1559,14 +1382,6 @@ int libetpan_message_register(struct mailengine * engine,
   struct folder_ref_info * folder_ref_info;
   struct mailstorage * storage;
   
-#if 0
-  r = message_folder_finder_store(&engine->msg_folder_finder, msg, folder);
-  if (r != MAIL_NO_ERROR) {
-    res = r;
-    goto err;
-  }
-#endif
-  
   if (folder != NULL)
     storage = folder->fld_storage;
   else
@@ -1579,15 +1394,11 @@ int libetpan_message_register(struct mailengine * engine,
   r = folder_message_add(folder_ref_info, msg);
   if (r != MAIL_NO_ERROR) {
     res = r;
-    goto delete;
+    goto err;
   }
   
   return MAIL_NO_ERROR;
   
- delete:
-#if 0
-  message_folder_finder_delete(&engine->msg_folder_finder, msg);
-#endif
  err:
   return res;
 }
@@ -1664,10 +1475,6 @@ void libetpan_engine_debug(struct mailengine * engine, FILE * f)
     storage_debug(storage_ref_info, f);
   }
 
-#if 0  
-  fprintf(f, "global message references: %i\n",
-      chash_count(engine->msg_folder_finder.message_hash));
-#endif
   fprintf(f, "mail engine debug -- end\n");
 }
 
