@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy.c,v 1.4 2005/06/01 16:04:44 hoa Exp $
+ * $Id: mailprivacy.c,v 1.6 2005/11/30 11:08:43 hoa Exp $
  */
 
 #include "mailprivacy.h"
@@ -671,7 +671,7 @@ mime_add_alternative(struct mailprivacy * privacy,
   if (r != MAIL_NO_ERROR)
     goto detach_alternative;
   
-  r = mailprivacy_get_part_from_file(privacy, 0,
+  r = mailprivacy_get_part_from_file(privacy, 0, 0,
       original_filename, &mime_copy);
   unlink(original_filename);
   if (r != MAIL_NO_ERROR) {
@@ -869,6 +869,16 @@ int mailprivacy_encrypt(struct mailprivacy * privacy,
     char * privacy_driver, char * privacy_encryption,
     struct mailmime * mime,
     struct mailmime ** result)
+{
+  return mailprivacy_encrypt_msg(privacy, privacy_driver, privacy_encryption,
+      NULL,  mime, result);
+}
+
+int mailprivacy_encrypt_msg(struct mailprivacy * privacy,
+    char * privacy_driver, char * privacy_encryption,
+    mailmessage * msg,
+    struct mailmime * mime,
+    struct mailmime ** result)
 {
   struct mailprivacy_protocol * protocol;
   struct mailprivacy_encryption * encryption;
@@ -885,7 +895,7 @@ int mailprivacy_encrypt(struct mailprivacy * privacy,
   if (encryption->encrypt == NULL)
     return MAIL_ERROR_NOT_IMPLEMENTED;
   
-  r = encryption->encrypt(privacy, mime, result);
+  r = encryption->encrypt(privacy, msg, mime, result);
   if (r != MAIL_NO_ERROR)
     return r;
   
