@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_smime.c,v 1.6 2005/06/01 16:04:44 hoa Exp $
+ * $Id: mailprivacy_smime.c,v 1.12 2005/12/07 14:57:57 hoa Exp $
  */
 
 #include "mailprivacy_smime.h"
@@ -55,6 +55,16 @@
   TODO : instance of privacy drivers
 */
 
+static int smime_command_passphrase(struct mailprivacy * privacy,
+    struct mailmessage * msg,
+    char * command,
+    char * passphrase,
+    char * stdoutfile, char * stderrfile);
+static char * get_passphrase(struct mailprivacy * privacy,
+    char * user_id);
+static int mailprivacy_smime_add_encryption_id(struct mailprivacy * privacy,
+    mailmessage * msg, char * encryption_id);
+
 static char cert_dir[PATH_MAX] = "";
 static chash * certificates = NULL;
 static chash * private_keys = NULL;
@@ -72,21 +82,44 @@ static char * get_private_key_file(char * email);
 static int smime_is_signed(struct mailmime * mime)
 {
   if (mime->mm_content_type != NULL) {
-    clistiter * cur;
-
-    for(cur = clist_begin(mime->mm_content_type->ct_parameters) ; cur != NULL ;
-        cur = clist_next(cur)) {
-      struct mailmime_parameter * param;
-          
-      param = cur->data;
-
-      if ((strcasecmp(param->pa_name, "protocol") == 0) &&
-          ((strcasecmp(param->pa_value, "application/x-pkcs7-signature") == 0) ||
-              (strcasecmp(param->pa_value, "application/pkcs7-signature") == 0)))
-        return 1;
+    if ((strcasecmp(mime->mm_content_type->ct_subtype, "x-pkcs7-mime") == 0) ||
+        (strcasecmp(mime->mm_content_type->ct_subtype, "pkcs7-mime") == 0)) {
+      clistiter * cur;
+      
+      for(cur = clist_begin(mime->mm_content_type->ct_parameters) ;
+          cur != NULL ;
+          cur = clist_next(cur)) {
+        struct mailmime_parameter * param;
+        
+        param = cur->data;
+        
+        if ((strcasecmp(param->pa_name, "smime-type") == 0) &&
+            (strcasecmp(param->pa_value, "signed-data") == 0))
+          return 1;
+      }
+      
+      return 0;
+    }
+    else {
+      clistiter * cur;
+      
+      for(cur = clist_begin(mime->mm_content_type->ct_parameters) ;
+          cur != NULL ;
+          cur = clist_next(cur)) {
+        struct mailmime_parameter * param;
+        
+        param = cur->data;
+        
+        if ((strcasecmp(param->pa_name, "protocol") == 0) &&
+            ((strcasecmp(param->pa_value,
+                  "application/x-pkcs7-signature") == 0) ||
+                (strcasecmp(param->pa_value,
+                    "application/pkcs7-signature") == 0)))
+          return 1;
+      }
     }
   }
-
+  
   return 0;
 }
 
@@ -94,67 +127,38 @@ static int smime_is_encrypted(struct mailmime * mime)
 {
   if (mime->mm_content_type != NULL) {
     if ((strcasecmp(mime->mm_content_type->ct_subtype, "x-pkcs7-mime") == 0) ||
-        (strcasecmp(mime->mm_content_type->ct_subtype, "pkcs7-mime") == 0))
+        (strcasecmp(mime->mm_content_type->ct_subtype, "pkcs7-mime") == 0)) {
+      clistiter * cur;
+      
+      for(cur = clist_begin(mime->mm_content_type->ct_parameters) ;
+          cur != NULL ;
+          cur = clist_next(cur)) {
+        struct mailmime_parameter * param;
+        
+        param = cur->data;
+        
+        if ((strcasecmp(param->pa_name, "smime-type") == 0) &&
+            (strcasecmp(param->pa_value, "signed-data") == 0))
+          return 0;
+      }
+      
       return 1;
+    }
   }
-
+  
   return 0;
 }
 
-#define BUF_SIZE 1024
 
 enum {
   NO_ERROR_SMIME = 0,
   ERROR_SMIME_CHECK,
   ERROR_SMIME_COMMAND,
   ERROR_SMIME_FILE,
+  ERROR_SMIME_NOPASSPHRASE,
 };
 
-/* write output to a file */
-
-static int get_smime_output(FILE * dest_f, char * command)
-{
-  FILE * p;
-  char buf[BUF_SIZE];
-  size_t size;
-  int res;
-  int status;
-  char command_redirected[PATH_MAX];
-  
-  snprintf(command_redirected, sizeof(command_redirected), "%s 2>&1", command);
-  
-  /*
-    flush buffer so that it is not flushed more than once when forking
-  */
-  fflush(dest_f);
-  
-  p = popen(command_redirected, "r");
-  if (p == NULL) {
-    res = ERROR_SMIME_COMMAND;
-    goto err;
-  }
-  
-  while ((size = fread(buf, 1, sizeof(buf), p)) != 0) {
-    size_t written;
-    
-    written = fwrite(buf, 1, size, dest_f);
-    if (written != size) {
-      res = ERROR_SMIME_FILE;
-      goto close;
-    }
-  }
-  status = pclose(p);
-  
-  if (WEXITSTATUS(status) != 0)
-    return ERROR_SMIME_CHECK;
-  else
-    return NO_ERROR_SMIME;
-  
- close:
-  pclose(p);
- err:
-  return res;
-}
+#define BUF_SIZE 1024
 
 static char * get_first_from_addr(struct mailmime * mime)
 {
@@ -191,6 +195,8 @@ static char * get_first_from_addr(struct mailmime * mime)
 #define SMIME_DECRYPT_FAILED "S/MIME decryption FAILED\r\n"
 #define SMIME_DECRYPT_SUCCESS "S/MIME decryption success\r\n"
 
+/* passphrase will be needed */
+
 static int smime_decrypt(struct mailprivacy * privacy,
     mailmessage * msg,
     struct mailmime * mime, struct mailmime ** result)
@@ -198,16 +204,13 @@ static int smime_decrypt(struct mailprivacy * privacy,
   char smime_filename[PATH_MAX];
   char quoted_smime_filename[PATH_MAX];
   char description_filename[PATH_MAX];
-  FILE * description_f;
   char decrypted_filename[PATH_MAX];
-  FILE * decrypted_f;
   char command[PATH_MAX];
   struct mailmime * description_mime;
   struct mailmime * decrypted_mime;
   int r;
   int res;
   int sign_ok;
-  char quoted_decrypted_filename[PATH_MAX];
   struct mailmime * multipart;
   char * smime_cert;
   char * smime_key;
@@ -228,15 +231,22 @@ static int smime_decrypt(struct mailprivacy * privacy,
   
   /* we are in a safe directory */
   
-  decrypted_f = mailprivacy_get_tmp_file(privacy,
-      decrypted_filename,
+  r = mailprivacy_get_tmp_filename(privacy, decrypted_filename,
       sizeof(decrypted_filename));
-  if (decrypted_f == NULL) {
+  if (r != MAIL_NO_ERROR) {
     res = MAIL_ERROR_FILE;
     goto unlink_smime;
   }
-  fclose(decrypted_f);
-
+  
+  /* description */
+  
+  r = mailprivacy_get_tmp_filename(privacy, description_filename,
+      sizeof(description_filename));
+  if (r != MAIL_NO_ERROR) {
+    res = MAIL_ERROR_FILE;
+    goto unlink_decrypted;
+  }
+  
   sign_ok = 0;
   for(iter = chash_begin(private_keys) ; iter != NULL ;
       iter = chash_next(private_keys, iter)) {
@@ -252,33 +262,11 @@ static int smime_decrypt(struct mailprivacy * privacy,
     email_buf[key.len] = '\0';
     email = email_buf;
     
-    /* description */
-    
-    description_f = mailprivacy_get_tmp_file(privacy,
-        description_filename,
-        sizeof(description_filename));
-    if (description_f == NULL) {
-      res = MAIL_ERROR_FILE;
-      goto unlink_decrypted;
-    }
-  
-    fprintf(description_f, SMIME_DECRYPT_DESCRIPTION);
-  
     /* get encryption key */
-
-#if 0  
-    email = get_first_from_addr(mime);
-    if (email == NULL) {
-      fclose(description_f);
-      res = MAIL_ERROR_INVAL;
-      goto unlink_description;
-    }
-#endif
-  
+    
     smime_key = get_private_key_file(email);
     smime_cert = get_cert_file(email);
     if ((smime_cert == NULL) || (smime_key == NULL)) {
-      fclose(description_f);
       res = MAIL_ERROR_INVAL;
       goto unlink_description;
     }
@@ -286,7 +274,6 @@ static int smime_decrypt(struct mailprivacy * privacy,
     r = mail_quote_filename(quoted_smime_cert, sizeof(quoted_smime_cert),
         smime_cert);
     if (r < 0) {
-      fclose(description_f);
       res = MAIL_ERROR_MEMORY;
       goto unlink_description;
     }
@@ -294,7 +281,6 @@ static int smime_decrypt(struct mailprivacy * privacy,
     r = mail_quote_filename(quoted_smime_key, sizeof(quoted_smime_key),
         smime_key);
     if (r < 0) {
-      fclose(description_f);
       res = MAIL_ERROR_MEMORY;
       goto unlink_description;
     }
@@ -304,66 +290,55 @@ static int smime_decrypt(struct mailprivacy * privacy,
     r = mail_quote_filename(quoted_smime_filename,
         sizeof(quoted_smime_filename), smime_filename);
     if (r < 0) {
-      fclose(description_f);
       res = MAIL_ERROR_MEMORY;
       goto unlink_description;
     }
-  
-    r = mail_quote_filename(quoted_decrypted_filename,
-        sizeof(quoted_decrypted_filename), decrypted_filename);
-    if (r < 0) {
-      fclose(description_f);
-      res = MAIL_ERROR_MEMORY;
-      goto unlink_description;
-    }
-  
+    
     sign_ok = 0;
-    snprintf(command, PATH_MAX,
-        "openssl smime -decrypt -in %s -out %s -inkey %s -recip %s",
-        quoted_smime_filename, quoted_decrypted_filename,
-        quoted_smime_key, quoted_smime_cert);
-  
-    r = get_smime_output(description_f, command);
+    snprintf(command, sizeof(command),
+        "openssl smime -decrypt -passin fd:0 -in '%s' -inkey '%s' -recip '%s'",
+        quoted_smime_filename, quoted_smime_key, quoted_smime_cert);
+    
+    unlink(description_filename);
+    r = smime_command_passphrase(privacy, msg, command,
+        email, decrypted_filename, description_filename);
     switch (r) {
     case NO_ERROR_SMIME:
       sign_ok = 1;
       break;
     case ERROR_SMIME_CHECK:
+    case ERROR_SMIME_NOPASSPHRASE:
       sign_ok = 0;
       break;
     case ERROR_SMIME_COMMAND:
-      fclose(description_f);
       res = MAIL_ERROR_COMMAND;
       goto unlink_description;
     case ERROR_SMIME_FILE:
-      fclose(description_f);
       res = MAIL_ERROR_FILE;
       goto unlink_description;
     }
     
     if (sign_ok) {
-      fprintf(description_f, SMIME_DECRYPT_SUCCESS);
-      fclose(description_f);
       break;
     }
-    else {
-      fclose(description_f);
-      unlink(description_filename);
-    }
   }
   
   if (!sign_ok) {
-    description_f = mailprivacy_get_tmp_file(privacy,
-        description_filename,
-        sizeof(description_filename));
-    if (description_f == NULL) {
-      res = MAIL_ERROR_FILE;
-      goto unlink_decrypted;
+    if (chash_count(private_keys) == 0) {
+      FILE * description_f;
+      
+      description_f = mailprivacy_get_tmp_file(privacy, description_filename,
+          sizeof(description_filename));
+      if (description_f == NULL) {
+        res = MAIL_ERROR_FILE;
+        goto unlink_decrypted;
+      }
+      fprintf(description_f, SMIME_DECRYPT_FAILED);
+      fclose(description_f);
     }
-    
-    fprintf(description_f, SMIME_DECRYPT_DESCRIPTION);
-    fprintf(description_f, SMIME_DECRYPT_FAILED);
-    fclose(description_f);
+  }
+  else {
+    mailprivacy_smime_encryption_id_list_clear(privacy, msg);
   }
   
   /* building multipart */
@@ -400,7 +375,7 @@ static int smime_decrypt(struct mailprivacy * privacy,
   
   /* building the decrypted part */
   
-  r = mailprivacy_get_part_from_file(privacy, 1,
+  r = mailprivacy_get_part_from_file(privacy, 1, 0,
       decrypted_filename, &decrypted_mime);
   if (r == MAIL_NO_ERROR) {
     /* adds the decrypted part */
@@ -455,13 +430,10 @@ smime_verify(struct mailprivacy * privacy,
   char command[PATH_MAX];
   int sign_ok;
   struct mailmime * description_mime;
-  FILE * description_f;
   char description_filename[PATH_MAX];
   struct mailmime * multipart;
   char stripped_filename[PATH_MAX];
   struct mailmime * stripped_mime;
-  char quoted_stripped_filename[PATH_MAX];
-  FILE * stripped_f;
   char check_CA[PATH_MAX];
   char quoted_CAfile[PATH_MAX];
   char noverify[PATH_MAX];
@@ -477,7 +449,7 @@ smime_verify(struct mailprivacy * privacy,
       goto err;
     }
     
-    snprintf(check_CA, sizeof(check_CA), "-CAfile %s", quoted_CAfile);
+    snprintf(check_CA, sizeof(check_CA), "-CAfile '%s'", quoted_CAfile);
   }
   
   * noverify = '\0';
@@ -495,71 +467,52 @@ smime_verify(struct mailprivacy * privacy,
     goto err;
   }
   
-  stripped_f = mailprivacy_get_tmp_file(privacy,
-      stripped_filename,
+  r = mailprivacy_get_tmp_filename(privacy,stripped_filename,
       sizeof(stripped_filename));
-  if (stripped_f == NULL) {
-    res = MAIL_ERROR_FILE;
+  if (r != MAIL_NO_ERROR) {
+    res = r;
     goto unlink_smime;
   }
-  fclose(stripped_f);
   
   /* description */
   
-  description_f = mailprivacy_get_tmp_file(privacy,
-      description_filename,
+  r = mailprivacy_get_tmp_filename(privacy, description_filename,
       sizeof(description_filename));
-  if (description_f == NULL) {
-    res = MAIL_ERROR_FILE;
+  if (r != MAIL_NO_ERROR) {
+    res = r;
     goto unlink_stripped;
   }
   
-  fprintf(description_f, SMIME_VERIFY_DESCRIPTION);
-  
   /* run the command */
 
   r = mail_quote_filename(quoted_smime_filename,
       sizeof(quoted_smime_filename), smime_filename);
   if (r < 0) {
-    fclose(description_f);
     res = MAIL_ERROR_MEMORY;
     goto unlink_description;
   }
 
-  r = mail_quote_filename(quoted_stripped_filename,
-      sizeof(quoted_stripped_filename), stripped_filename);
-  if (r < 0) {
-    fclose(description_f);
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_description;
-  }
-  
   sign_ok = 0;
-  snprintf(command, PATH_MAX, "openssl smime -verify -in %s -out %s %s %s",
-      quoted_smime_filename, quoted_stripped_filename, check_CA, noverify);
+  snprintf(command, sizeof(command), "openssl smime -verify -in '%s' %s %s",
+      quoted_smime_filename, check_CA, noverify);
   
-  r = get_smime_output(description_f, command);
+  r = smime_command_passphrase(privacy, msg, command,
+      NULL, stripped_filename, description_filename);
   switch (r) {
   case NO_ERROR_SMIME:
     sign_ok = 1;
     break;
+  case ERROR_SMIME_NOPASSPHRASE:
   case ERROR_SMIME_CHECK:
     sign_ok = 0;
     break;
   case ERROR_SMIME_COMMAND:
-    fclose(description_f);
     res = MAIL_ERROR_COMMAND;
     goto unlink_description;
   case ERROR_SMIME_FILE:
-    fclose(description_f);
     res = MAIL_ERROR_FILE;
     goto unlink_description;
   }
-  if (sign_ok)
-    fprintf(description_f, SMIME_VERIFY_SUCCESS);
-  else
-    fprintf(description_f, SMIME_VERIFY_FAILED);
-  fclose(description_f);
   
   /* building multipart */
   
@@ -595,18 +548,20 @@ smime_verify(struct mailprivacy * privacy,
   
   /* insert the signed part */
   if (!sign_ok) {
-    clistiter * child_iter;
-    struct mailmime * child;
-    
-    child_iter = clist_begin(mime->mm_data.mm_multipart.mm_mp_list);
-    child = clist_content(child_iter);
-    
-    r = mailprivacy_fetch_mime_body_to_file(privacy,
-        stripped_filename, sizeof(stripped_filename),
-        msg, child);
+    if (mime->mm_type == MAILMIME_MULTIPLE) {
+      clistiter * child_iter;
+      struct mailmime * child;
+      
+      child_iter = clist_begin(mime->mm_data.mm_multipart.mm_mp_list);
+      child = clist_content(child_iter);
+      
+      r = mailprivacy_fetch_mime_body_to_file(privacy,
+          stripped_filename, sizeof(stripped_filename),
+          msg, child);
+    }
   }
   
-  r = mailprivacy_get_part_from_file(privacy, 1,
+  r = mailprivacy_get_part_from_file(privacy, 1, 0,
       stripped_filename, &stripped_mime);
   if (r != MAIL_NO_ERROR) {
     mailprivacy_mime_clear(multipart);
@@ -627,7 +582,7 @@ smime_verify(struct mailprivacy * privacy,
   
   unlink(description_filename);
   unlink(stripped_filename);
-  unlink(smime_filename);
+  // unlink(smime_filename);
   
   * result = multipart;
   
@@ -652,7 +607,7 @@ static int smime_test_encrypted(struct mailprivacy * privacy,
     return smime_is_signed(mime);
     
   case MAILMIME_SINGLE:
-    return smime_is_encrypted(mime);
+    return smime_is_encrypted(mime) || smime_is_signed(mime);
   }
   
   return 0;
@@ -683,6 +638,8 @@ static int smime_handler(struct mailprivacy * privacy,
     r = MAIL_ERROR_INVAL;
     if (smime_is_encrypted(mime))
       r = smime_decrypt(privacy, msg, mime, &alternative_mime);
+    else if (smime_is_signed(mime))
+      r = smime_verify(privacy, msg, mime, &alternative_mime);
     
     if (r != MAIL_NO_ERROR)
       return r;
@@ -722,7 +679,10 @@ static void strip_mime_headers(struct mailmime * mime)
   }
 }
 
+/* passphrase is needed */
+
 static int smime_sign(struct mailprivacy * privacy,
+    mailmessage * msg,
     struct mailmime * mime, struct mailmime ** result)
 {
   char signed_filename[PATH_MAX];
@@ -730,10 +690,9 @@ static int smime_sign(struct mailprivacy * privacy,
   int res;
   int r;
   int col;
+  char description_filename[PATH_MAX];
   char signature_filename[PATH_MAX];
-  FILE * signature_f;
   char command[PATH_MAX];
-  char quoted_signature_filename[PATH_MAX];
   char quoted_signed_filename[PATH_MAX];
   struct mailmime * signed_mime;
   char * smime_cert;
@@ -756,7 +715,7 @@ static int smime_sign(struct mailprivacy * privacy,
     res = MAIL_ERROR_INVAL;
     goto err;
   }
-  
+
   /* part to sign */
 
   /* encode quoted printable all text parts */
@@ -782,71 +741,84 @@ static int smime_sign(struct mailprivacy * privacy,
   
   /* prepare destination file for signature */
   
-  signature_f = mailprivacy_get_tmp_file(privacy,
-      signature_filename,
+  r = mailprivacy_get_tmp_filename(privacy, signature_filename,
       sizeof(signature_filename));
-  if (signature_f == NULL) {
-    res = MAIL_ERROR_FILE;
+  if (r != MAIL_NO_ERROR) {
+    res = r;
     goto unlink_signed;
   }
-  fclose(signature_f);
+
+  r = mailprivacy_get_tmp_filename(privacy, description_filename,
+      sizeof(description_filename));
+  if (r != MAIL_NO_ERROR) {
+    res = r;
+    goto unlink_signature;
+  }
   
   r = mail_quote_filename(quoted_signed_filename,
        sizeof(quoted_signed_filename), signed_filename);
   if (r < 0) {
     res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
+    goto unlink_description;
   }
   
-  r = mail_quote_filename(quoted_signature_filename,
-      sizeof(quoted_signature_filename), signature_filename);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
-  }
-
   r = mail_quote_filename(quoted_smime_key,
        sizeof(quoted_smime_key), smime_key);
   if (r < 0) {
     res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
+    goto unlink_description;
   }
 
   r = mail_quote_filename(quoted_smime_cert,
        sizeof(quoted_smime_cert), smime_cert);
   if (r < 0) {
     res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
+    goto unlink_description;
   }
-  
+
   snprintf(command, sizeof(command),
-      "openssl smime -sign -in %s -out %s -signer %s -inkey %s 2>/dev/null",
-      quoted_signed_filename, quoted_signature_filename,
+      "openssl smime -sign -passin fd:0 -in '%s' -signer '%s' -inkey '%s'",
+      quoted_signed_filename,
       quoted_smime_cert, quoted_smime_key);
-  
-  r = system(command);
-  if (WEXITSTATUS(r) != 0) {
+
+  r = smime_command_passphrase(privacy, msg, command,
+      email, signature_filename, description_filename);
+  switch (r) {
+  case NO_ERROR_SMIME:
+    break;
+  case ERROR_SMIME_NOPASSPHRASE:
+  case ERROR_SMIME_CHECK:
     res = MAIL_ERROR_COMMAND;
-    goto unlink_signature;
+    goto unlink_description;
+    break;
+  case ERROR_SMIME_COMMAND:
+    res = MAIL_ERROR_COMMAND;
+    goto unlink_description;
+  case ERROR_SMIME_FILE:
+    res = MAIL_ERROR_FILE;
+    goto unlink_description;
   }
   
   /* signature part */
   
-  r = mailprivacy_get_part_from_file(privacy, 0,
+  r = mailprivacy_get_part_from_file(privacy, 0, 0,
       signature_filename, &signed_mime);
   if (r != MAIL_NO_ERROR) {
     res = r;
-    goto unlink_signature;
+    goto unlink_description;
   }
   strip_mime_headers(signed_mime);
   
-  unlink(signature_filename);
-  unlink(signed_filename);
+  unlink(description_filename);
+  // unlink(signature_filename);
+  // unlink(signed_filename);
   
   * result = signed_mime;
   
   return MAIL_NO_ERROR;
   
+ unlink_description:
+  unlink(description_filename);
  unlink_signature:
   unlink(signature_filename);
  unlink_signed:
@@ -882,9 +854,13 @@ static int recipient_add_mb(char * recipient, size_t * len,
   buflen = strlen(quoted_filename + 1);
   if (buflen >= * len)
     return MAIL_ERROR_MEMORY;
-    
+  
+  strncat(recipient, "\'", * len);
+  (* len) --;
   strncat(recipient, quoted_filename, * len);
   (* len) -= buflen;
+  strncat(recipient, "\'", * len);
+  (* len) --;
   strncat(recipient, " ", * len);
   (* len) --;
   
@@ -1008,18 +984,18 @@ static int collect_smime_cert(char * recipient, size_t size,
 
 
 static int smime_encrypt(struct mailprivacy * privacy,
+    mailmessage * msg,
     struct mailmime * mime, struct mailmime ** result)
 {
   char encrypted_filename[PATH_MAX];
-  FILE * encrypted_f;
   int res;
   int r;
   int col;
+  char description_filename[PATH_MAX];
   char decrypted_filename[PATH_MAX];
   FILE * decrypted_f;
   char command[PATH_MAX];
   char quoted_decrypted_filename[PATH_MAX];
-  char quoted_encrypted_filename[PATH_MAX];
   struct mailmime * encrypted_mime;
   struct mailmime * root;
   struct mailimf_fields * fields;
@@ -1066,56 +1042,68 @@ static int smime_encrypt(struct mailprivacy * privacy,
   
   /* prepare destination file for encryption */
   
-  encrypted_f = mailprivacy_get_tmp_file(privacy,
-      encrypted_filename,
+  r = mailprivacy_get_tmp_filename(privacy, encrypted_filename,
       sizeof(encrypted_filename));
-  if (encrypted_f == NULL) {
+  if (r != MAIL_NO_ERROR) {
     res = MAIL_ERROR_FILE;
     goto unlink_decrypted;
   }
-  fclose(encrypted_f);
+  
+  r = mailprivacy_get_tmp_filename(privacy, description_filename,
+      sizeof(description_filename));
+  if (r != MAIL_NO_ERROR) {
+    res = MAIL_ERROR_FILE;
+    goto unlink_encrypted;
+  }
   
   r = mail_quote_filename(quoted_decrypted_filename,
       sizeof(quoted_decrypted_filename), decrypted_filename);
   if (r < 0) {
     res = MAIL_ERROR_MEMORY;
-    goto unlink_encrypted;
+    goto unlink_description;
   }
   
-  r = mail_quote_filename(quoted_encrypted_filename,
-       sizeof(quoted_encrypted_filename), encrypted_filename);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_encrypted;
-  }
+  snprintf(command, sizeof(command), "openssl smime -encrypt -in '%s' %s",
+      quoted_decrypted_filename, recipient);
   
-  snprintf(command, sizeof(command),
-      "openssl smime -encrypt -in %s -out %s %s 2>/dev/null",
-      quoted_decrypted_filename, quoted_encrypted_filename, recipient);
-  
-  r = system(command);
-  if (WEXITSTATUS(r) != 0) {
+  r = smime_command_passphrase(privacy, msg, command,
+      NULL, encrypted_filename, description_filename);
+  switch (r) {
+  case NO_ERROR_SMIME:
+    break;
+  case ERROR_SMIME_NOPASSPHRASE:
+  case ERROR_SMIME_CHECK:
+    res = MAIL_ERROR_COMMAND;
+    goto unlink_description;
+    break;
+  case ERROR_SMIME_COMMAND:
     res = MAIL_ERROR_COMMAND;
     goto unlink_encrypted;
+  case ERROR_SMIME_FILE:
+    res = MAIL_ERROR_FILE;
+    goto unlink_description;
   }
   
   /* encrypted part */
   
-  r = mailprivacy_get_part_from_file(privacy, 0,
+  r = mailprivacy_get_part_from_file(privacy, 0, 0,
       encrypted_filename, &encrypted_mime);
   if (r != MAIL_NO_ERROR) {
     res = r;
-    goto unlink_encrypted;
+    goto unlink_description;
   }
   strip_mime_headers(encrypted_mime);
 
+  unlink(description_filename);
   unlink(encrypted_filename);
   unlink(decrypted_filename);
   
   * result = encrypted_mime;
   
   return MAIL_NO_ERROR;
-  
+
+ unlink_description:
+  unlink(description_filename);
  unlink_encrypted:
   unlink(encrypted_filename);
  unlink_decrypted:
@@ -1125,194 +1113,67 @@ static int smime_encrypt(struct mailprivacy * privacy,
 }
 
 
+/* passphrase will be needed */
+
 static int smime_sign_encrypt(struct mailprivacy * privacy,
+    mailmessage * msg,
     struct mailmime * mime, struct mailmime ** result)
 {
-  char encrypted_filename[PATH_MAX];
-  FILE * encrypted_f;
-  int res;
+  struct mailmime * signed_part;
+  struct mailmime * encrypted;
   int r;
-  int col;
-  char signature_filename[PATH_MAX];
-  FILE * signature_f;
-  char decrypted_filename[PATH_MAX];
-  FILE * decrypted_f;
-  char command[PATH_MAX];
-  char quoted_decrypted_filename[PATH_MAX];
-  char quoted_encrypted_filename[PATH_MAX];
-  char quoted_signature_filename[PATH_MAX];
-  struct mailmime * encrypted_mime;
-  struct mailmime * root;
-  struct mailimf_fields * fields;
-  char recipient[PATH_MAX];
-  char * smime_cert;
-  char * smime_key;
-  char quoted_smime_cert[PATH_MAX];
-  char quoted_smime_key[PATH_MAX];
-  char * email;
+  int res;
   
-  root = mime;
-  while (root->mm_parent != NULL)
-    root = root->mm_parent;
-  
-  fields = NULL;
-  if (root->mm_type == MAILMIME_MESSAGE)
-    fields = root->mm_data.mm_message.mm_fields;
-  
-  /* recipient */
-  r = collect_smime_cert(recipient, sizeof(recipient), fields);
+  r = smime_sign(privacy, msg, mime, &signed_part);
   if (r != MAIL_NO_ERROR) {
     res = r;
     goto err;
   }
-
-  /* get signing key */
   
-  email = get_first_from_addr(mime);
-  if (email == NULL) {
-    res = MAIL_ERROR_INVAL;
-    goto err;
-  }
-  
-  smime_key = get_private_key_file(email);
-  smime_cert = get_cert_file(email);
-  if ((smime_cert == NULL) || (smime_key == NULL)) {
-    res = MAIL_ERROR_INVAL;
-    goto err;
-  }
-  
-  /* part to encrypt */
-
-  /* encode quoted printable all text parts */
-  
-  mailprivacy_prepare_mime(mime);
-  
-  decrypted_f = mailprivacy_get_tmp_file(privacy,
-      decrypted_filename, sizeof(decrypted_filename));
-  if (decrypted_f == NULL) {
-    res = MAIL_ERROR_FILE;
-    goto err;
-  }
-  
-  col = 0;
-  r = mailmime_write(decrypted_f, &col, mime);
-  if (r != MAILIMF_NO_ERROR) {
-    fclose(decrypted_f);
-    res = MAIL_ERROR_FILE;
-    goto unlink_decrypted;
-  }
-  
-  fclose(decrypted_f);
-  
-  /* prepare destination file for signature */
-  
-  signature_f = mailprivacy_get_tmp_file(privacy,
-      signature_filename,
-      sizeof(signature_filename));
-  if (signature_f == NULL) {
-    res = MAIL_ERROR_FILE;
-    goto unlink_decrypted;
-  }
-  fclose(signature_f);
-  
-  r = mail_quote_filename(quoted_decrypted_filename,
-      sizeof(quoted_decrypted_filename), decrypted_filename);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
-  }
-  
-  r = mail_quote_filename(quoted_signature_filename,
-      sizeof(quoted_signature_filename), signature_filename);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
-  }
-
-  r = mail_quote_filename(quoted_smime_key,
-       sizeof(quoted_smime_key), smime_key);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
-  }
-
-  r = mail_quote_filename(quoted_smime_cert,
-       sizeof(quoted_smime_cert), smime_cert);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_signature;
-  }
-  
-  snprintf(command, sizeof(command),
-      "openssl smime -sign -in %s -out %s -signer %s -inkey %s 2>/dev/null",
-      quoted_decrypted_filename, quoted_signature_filename,
-      quoted_smime_cert, quoted_smime_key);
-  
-  r = system(command);
-  if (WEXITSTATUS(r) != 0) {
-    res = MAIL_ERROR_COMMAND;
-    goto unlink_signature;
-  }
-  
-  
-  /* prepare destination file for encryption */
-  
-  encrypted_f = mailprivacy_get_tmp_file(privacy,
-      encrypted_filename,
-      sizeof(encrypted_filename));
-  if (encrypted_f == NULL) {
-    res = MAIL_ERROR_FILE;
-    goto unlink_signature;
-  }
-  fclose(encrypted_f);
-  
-  r = mail_quote_filename(quoted_encrypted_filename,
-       sizeof(quoted_encrypted_filename), encrypted_filename);
-  if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
-    goto unlink_encrypted;
-  }
-  
-  snprintf(command, sizeof(command),
-      "openssl smime -encrypt -in %s -out %s %s 2>/dev/null",
-      quoted_signature_filename, quoted_encrypted_filename, recipient);
-  
-  r = system(command);
-  if (WEXITSTATUS(r) != 0) {
-    res = MAIL_ERROR_COMMAND;
-    goto unlink_encrypted;
-  }
-  
-  /* encrypted part */
-  
-  r = mailprivacy_get_part_from_file(privacy, 0,
-      encrypted_filename, &encrypted_mime);
+  r = smime_encrypt(privacy, msg, signed_part, &encrypted);
   if (r != MAIL_NO_ERROR) {
     res = r;
-    goto unlink_encrypted;
+    goto free_signed;
   }
-  strip_mime_headers(encrypted_mime);
-
-  unlink(encrypted_filename);
-  unlink(signature_filename);
-  unlink(decrypted_filename);
   
-  * result = encrypted_mime;
+  * result = encrypted;
   
   return MAIL_NO_ERROR;
   
- unlink_encrypted:
-  unlink(encrypted_filename);
- unlink_signature:
-  unlink(signature_filename);
- unlink_decrypted:
-  unlink(decrypted_filename);
+ free_signed:
+  mailprivacy_mime_clear(signed_part);
+  mailmime_free(signed_part);
  err:
   return res;
 }
 
 
+#if defined (_MSC_VER) || defined ( __SUNPRO_CC)
+static struct mailprivacy_encryption smime_encryption_tab[] = {
+  /* S/MIME signed part */
+  {
+    /* name */ "signed",
+    /* description */ "S/MIME signed part",
+    /* encrypt */ smime_sign,
+  },
+  
+  /* S/MIME encrypted part */
+  
+  {
+    /* name */ "encrypted",
+    /* description */ "S/MIME encrypted part",
+    /* encrypt */ smime_encrypt,
+  },
 
+  /* S/MIME signed & encrypted part */
+  
+  {
+    /* name */ "signed-encrypted",
+    /* description */ "S/MIME signed & encrypted part",
+    /* encrypt */ smime_sign_encrypt,
+  },
+};
+#else
 static struct mailprivacy_encryption smime_encryption_tab[] = {
   /* S/MIME signed part */
   {
@@ -1337,7 +1198,22 @@ static struct mailprivacy_encryption smime_encryption_tab[] = {
     .encrypt = smime_sign_encrypt,
   },
 };
+#endif
 
+#if defined (_MSC_VER) || defined ( __SUNPRO_CC)
+static struct mailprivacy_protocol smime_protocol = {
+  /* name */ "smime",
+  /* description */ "S/MIME",
+  
+  /* is_encrypted */ smime_test_encrypted,
+  /* decrypt */ smime_handler,
+  
+  /* encryption_count */
+  (sizeof(smime_encryption_tab) / sizeof(smime_encryption_tab[0])),
+  
+  /* encryption_tab */ smime_encryption_tab,
+};
+#else
 static struct mailprivacy_protocol smime_protocol = {
   .name = "smime",
   .description = "S/MIME",
@@ -1350,6 +1226,7 @@ static struct mailprivacy_protocol smime_protocol = {
   
   .encryption_tab = smime_encryption_tab,
 };
+#endif
 
 int mailprivacy_smime_init(struct mailprivacy * privacy)
 {
@@ -1494,16 +1371,20 @@ void mailprivacy_smime_set_cert_dir(struct mailprivacy * privacy,
     return;
   
   while ((ent = readdir(dir)) != NULL) {
+    char quoted_filename[PATH_MAX];
     char filename[PATH_MAX];
     char command[PATH_MAX];
     char buf[MAX_EMAIL_SIZE];
     FILE * p;
+    int r;
     
     snprintf(filename, sizeof(filename),
         "%s/%s", directory, ent->d_name);
     
+    r = mail_quote_filename(quoted_filename, sizeof(quoted_filename), filename);
+    
     snprintf(command, sizeof(command),
-        "openssl x509 -email -noout -in %s 2>/dev/null", filename);
+        "openssl x509 -email -noout -in '%s' 2>/dev/null", quoted_filename);
     
     p = popen(command, "r");
     if (p == NULL)
@@ -1687,7 +1568,7 @@ static int get_cert_from_sig(struct mailprivacy * privacy,
   }
 
   snprintf(command, sizeof(command),
-      "openssl pkcs7 -inform DER -in %s -out %s -print_certs 2>/dev/null",
+      "openssl pkcs7 -inform DER -in '%s' -out '%s' -print_certs 2>/dev/null",
       quoted_signature_filename, quoted_store_cert_filename);
   
   r = system(command);
@@ -1765,3 +1646,324 @@ void mailprivacy_smime_set_private_keys_dir(struct mailprivacy * privacy,
   }
   closedir(dir);
 }
+
+/*
+  - try private keys without passphrase and try those
+      for which we already have a passphrase,
+  - try recipient list and ask passphrase,
+  - then, ask passphrase for all private keys
+*/
+
+static int smime_command_passphrase(struct mailprivacy * privacy,
+    struct mailmessage * msg,
+    char * command,
+    char * userid,
+    char * stdoutfile, char * stderrfile)
+{
+  pid_t pid;
+  int passphrase_input[2];
+  int fd_err;
+  int fd_out;
+  int r;
+  char * passphrase;
+  int bad_passphrase;
+  int res;
+  
+  bad_passphrase = 0;
+  
+  passphrase = NULL;
+  if (userid != NULL)
+    passphrase = get_passphrase(privacy, userid);
+  
+  fd_out = open(stdoutfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
+  if (fd_out < 0) {
+    res = ERROR_SMIME_FILE;
+    goto err;
+  }
+  
+  fd_err = open(stderrfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
+  if (fd_err < 0) {
+    res = ERROR_SMIME_FILE;
+    goto close_out;
+  }
+  
+  r = pipe(passphrase_input);
+  if (r < 0) {
+    res = ERROR_SMIME_FILE;
+    goto close_err;
+  }
+  
+  pid = fork();
+  switch (pid) {
+  case -1:
+    return ERROR_SMIME_COMMAND;
+    
+  case 0:
+    /* child */
+    {
+      int status;
+      
+      /* close unneeded fd */
+      close(passphrase_input[1]);
+      
+      dup2(passphrase_input[0], 0);
+      close(passphrase_input[0]);
+      dup2(fd_out, 1);
+      close(fd_out);
+      dup2(fd_err, 2);
+      close(fd_err);
+      
+      status = system(command);
+      
+      exit(WEXITSTATUS(status));
+    }
+    break;
+    
+  default:
+    /* parent */
+    {
+      int status;
+      
+      /* close unneeded fd */
+      close(fd_err);
+      close(fd_out);
+      close(passphrase_input[0]);
+      
+      if ((passphrase != NULL) && (strlen(passphrase) > 0)) {
+        write(passphrase_input[1], passphrase, strlen(passphrase));
+      }
+      else {
+        /* dummy password */
+        write(passphrase_input[1], "*dummy*", 7);
+      }
+      close(passphrase_input[1]);
+      
+      waitpid(pid, &status, 0);
+      
+      if (WEXITSTATUS(status) != 0)
+        bad_passphrase = 1;
+    }
+    break;
+  }
+  
+  if (bad_passphrase) {
+    if (userid != NULL) {
+      mailprivacy_smime_add_encryption_id(privacy, msg, userid);
+      return ERROR_SMIME_NOPASSPHRASE;
+    }
+    
+    return ERROR_SMIME_CHECK;
+  }
+  
+  return NO_ERROR_SMIME;
+  
+ close_err:
+  close(fd_err);
+ close_out:
+  close(fd_out);
+ err:
+  return res;
+}
+
+
+
+#ifdef LIBETPAN_REENTRANT
+static pthread_mutex_t encryption_id_hash_lock = PTHREAD_MUTEX_INITIALIZER;
+#endif
+static chash * encryption_id_hash = NULL;
+
+static clist * get_list(struct mailprivacy * privacy, mailmessage * msg)
+{
+  clist * encryption_id_list;
+  
+  encryption_id_list = NULL;
+  if (encryption_id_hash != NULL) {
+    chashdatum key;
+    chashdatum value;
+    int r;
+    
+    key.data = &msg;
+    key.len = sizeof(msg);
+    r = chash_get(encryption_id_hash, &key, &value);
+    if (r == 0) {
+      encryption_id_list = value.data;
+    }
+  }
+  
+  return encryption_id_list;
+}
+
+void mailprivacy_smime_encryption_id_list_clear(struct mailprivacy * privacy,
+    mailmessage * msg)
+{
+  clist * encryption_id_list;
+  clistiter * iter;
+  
+#ifdef LIBETPAN_REENTRANT
+  pthread_mutex_lock(&encryption_id_hash_lock);
+#endif
+  encryption_id_list = get_list(privacy, msg);
+  if (encryption_id_list != NULL) {
+    chashdatum key;
+    
+    for(iter = clist_begin(encryption_id_list) ;
+        iter != NULL ; iter = clist_next(iter)) {
+      char * str;
+      
+      str = clist_content(iter);
+      free(str);
+    }
+    clist_free(encryption_id_list);
+    
+    key.data = &msg;
+    key.len = sizeof(msg);
+    chash_delete(encryption_id_hash, &key, NULL);
+    
+    if (chash_count(encryption_id_hash) == 0) {
+      chash_free(encryption_id_hash);
+      encryption_id_hash = NULL;
+    }
+  }
+#ifdef LIBETPAN_REENTRANT
+  pthread_mutex_unlock(&encryption_id_hash_lock);
+#endif
+}
+
+clist * mailprivacy_smime_encryption_id_list(struct mailprivacy * privacy,
+    mailmessage * msg)
+{
+  clist * encryption_id_list;
+  
+#ifdef LIBETPAN_REENTRANT
+  pthread_mutex_lock(&encryption_id_hash_lock);
+#endif
+  encryption_id_list = get_list(privacy, msg);
+#ifdef LIBETPAN_REENTRANT
+  pthread_mutex_unlock(&encryption_id_hash_lock);
+#endif
+  
+  return encryption_id_list;
+}
+
+static int mailprivacy_smime_add_encryption_id(struct mailprivacy * privacy,
+    mailmessage * msg, char * encryption_id)
+{
+  clist * encryption_id_list;
+  int r;
+  int res;
+  
+#ifdef LIBETPAN_REENTRANT
+  pthread_mutex_lock(&encryption_id_hash_lock);
+#endif
+  
+  res = -1;
+  
+  encryption_id_list = get_list(privacy, msg);
+  if (encryption_id_list == NULL) {
+    if (encryption_id_hash == NULL)
+      encryption_id_hash = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
+    
+    if (encryption_id_hash != NULL) {
+      encryption_id_list = clist_new();
+      if (encryption_id_list != NULL) {
+        chashdatum key;
+        chashdatum value;
+        
+        key.data = &msg;
+        key.len = sizeof(msg);
+        value.data = encryption_id_list;
+        value.len = 0;
+        r = chash_set(encryption_id_hash, &key, &value, NULL);
+        if (r < 0)
+          clist_free(encryption_id_list);
+      }
+    }
+  }
+  
+  encryption_id_list = get_list(privacy, msg);
+  if (encryption_id_list != NULL) {
+    char * str;
+    
+    str = strdup(encryption_id);
+    if (str != NULL) {
+      r = clist_append(encryption_id_list, str);
+      if (r < 0) {
+        free(str);
+      }
+      else {
+        res = 0;
+      }
+    }
+  }
+  
+#ifdef LIBETPAN_REENTRANT
+  pthread_mutex_unlock(&encryption_id_hash_lock);
+#endif
+  
+  return res;
+}
+
+static chash * passphrase_hash = NULL;
+
+int mailprivacy_smime_set_encryption_id(struct mailprivacy * privacy,
+    char * user_id, char * passphrase)
+{
+  chashdatum key;
+  chashdatum value;
+  int r;
+  char buf[MAX_EMAIL_SIZE];
+  char * n;
+  
+  strncpy(buf, user_id, sizeof(buf));
+  buf[sizeof(buf) - 1] = '\0';
+  for(n = buf ; * n != '\0' ; n ++)
+    * n = toupper((unsigned char) * n);
+  
+  if (passphrase_hash == NULL) {
+    passphrase_hash = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYALL);
+    if (passphrase_hash == NULL)
+      return MAIL_ERROR_MEMORY;
+  }
+  
+  key.data = buf;
+  key.len = strlen(buf) + 1;
+  value.data = passphrase;
+  value.len = strlen(passphrase) + 1;
+  
+  r = chash_set(passphrase_hash, &key, &value, NULL);
+  if (r < 0) {
+    return MAIL_ERROR_MEMORY;
+  }
+  
+  return MAIL_NO_ERROR;
+}
+
+static char * get_passphrase(struct mailprivacy * privacy,
+    char * user_id)
+{
+  chashdatum key;
+  chashdatum value;
+  int r;
+  char * passphrase;
+  char buf[MAX_EMAIL_SIZE];
+  char * n;
+  
+  strncpy(buf, user_id, sizeof(buf));
+  buf[sizeof(buf) - 1] = '\0';
+  for(n = buf ; * n != '\0' ; n ++)
+    * n = toupper((unsigned char) * n);
+  
+  if (passphrase_hash == NULL)
+    return NULL;
+  
+  key.data = buf;
+  key.len = strlen(buf) + 1;
+  
+  r = chash_get(passphrase_hash, &key, &value);
+  if (r < 0)
+    return NULL;
+  
+  passphrase = strdup(value.data);
+  
+  return passphrase;
+}
