@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_tools.c,v 1.4 2005/01/28 01:43:12 hoa Exp $
+ * $Id: mailprivacy_tools.c,v 1.8 2005/12/21 23:49:23 hoa Exp $
  */
 
 #include "mailprivacy_tools.h"
@@ -122,6 +122,19 @@ FILE * mailprivacy_get_tmp_file(struct mailprivacy * privacy,
   return get_tmp_file(filename);
 }
 
+int mailprivacy_get_tmp_filename(struct mailprivacy * privacy,
+    char * filename, size_t size)
+{
+  FILE * f;
+  
+  f = mailprivacy_get_tmp_file(privacy, filename, size);
+  if (f == NULL)
+    return MAIL_ERROR_FILE;
+  
+  fclose(f);
+  
+  return MAIL_NO_ERROR;
+}
 
 static char * dup_file(struct mailprivacy * privacy,
     char * source_filename)
@@ -187,7 +200,8 @@ static char * dup_file(struct mailprivacy * privacy,
 
 static int mime_data_replace(struct mailprivacy * privacy,
     int encoding_type,
-    struct mailmime_data * data)
+    struct mailmime_data * data,
+    int reencode)
 {
   char filename[PATH_MAX];
   FILE * f;
@@ -209,29 +223,31 @@ static int mime_data_replace(struct mailprivacy * privacy,
   }
   
   decoded = 0;
-  if (encoding_type != -1) {
-    char * content;
-    size_t content_len;
-    size_t cur_token;
+  if (reencode) {
+    if (encoding_type != -1) {
+      char * content;
+      size_t content_len;
+      size_t cur_token;
     
-    cur_token = 0;
-    r = mailmime_part_parse(data->dt_data.dt_text.dt_data,
-        data->dt_data.dt_text.dt_length,
-        &cur_token, encoding_type, &content, &content_len);
+      cur_token = 0;
+      r = mailmime_part_parse(data->dt_data.dt_text.dt_data,
+          data->dt_data.dt_text.dt_length,
+          &cur_token, encoding_type, &content, &content_len);
     
-    if (r == MAILIMF_NO_ERROR) {
-      /* write decoded */
-      written = fwrite(content, 1, content_len, f);
-      if (written != content_len) {
-        fclose(f);
-        unlink(filename);
-        res = MAIL_ERROR_FILE;
-        goto err;
-      }
-      mmap_string_unref(content);
+      if (r == MAILIMF_NO_ERROR) {
+        /* write decoded */
+        written = fwrite(content, 1, content_len, f);
+        if (written != content_len) {
+          fclose(f);
+          unlink(filename);
+          res = MAIL_ERROR_FILE;
+          goto err;
+        }
+        mmap_string_unref(content);
       
-      decoded = 1;
-      data->dt_encoded = 0;
+        decoded = 1;
+        data->dt_encoded = 0;
+      }
     }
   }
   
@@ -272,7 +288,7 @@ static int mime_data_replace(struct mailprivacy * privacy,
 */
 
 static int recursive_replace_single_parts(struct mailprivacy * privacy,
-    struct mailmime * mime)
+    struct mailmime * mime, int reencode)
 {
   int r;
   int res;
@@ -294,7 +310,8 @@ static int recursive_replace_single_parts(struct mailprivacy * privacy,
       else
         encoding_type = -1;
       
-      r = mime_data_replace(privacy, encoding_type, mime->mm_data.mm_single);
+      r = mime_data_replace(privacy, encoding_type,
+          mime->mm_data.mm_single, reencode);
       if (r != MAIL_NO_ERROR) {
         res = r;
         goto err;
@@ -305,7 +322,7 @@ static int recursive_replace_single_parts(struct mailprivacy * privacy,
   case MAILMIME_MULTIPLE:
     if (mime->mm_data.mm_multipart.mm_preamble != NULL) {
       r = mime_data_replace(privacy, -1,
-          mime->mm_data.mm_multipart.mm_preamble);
+          mime->mm_data.mm_multipart.mm_preamble, reencode);
       if (r != MAIL_NO_ERROR) {
         res = r;
         goto err;
@@ -314,7 +331,7 @@ static int recursive_replace_single_parts(struct mailprivacy * privacy,
     
     if (mime->mm_data.mm_multipart.mm_epilogue != NULL) {
       r = mime_data_replace(privacy, -1,
-          mime->mm_data.mm_multipart.mm_epilogue);
+          mime->mm_data.mm_multipart.mm_epilogue, reencode);
       if (r != MAIL_NO_ERROR) {
         res = r;
         goto err;
@@ -327,7 +344,7 @@ static int recursive_replace_single_parts(struct mailprivacy * privacy,
       
       child = clist_content(cur);
       
-      r = recursive_replace_single_parts(privacy, child);
+      r = recursive_replace_single_parts(privacy, child, reencode);
       if (r != MAIL_NO_ERROR) {
         res = r;
         goto err;
@@ -339,7 +356,7 @@ static int recursive_replace_single_parts(struct mailprivacy * privacy,
   case MAILMIME_MESSAGE:
     if (mime->mm_data.mm_message.mm_msg_mime != NULL) {
       r = recursive_replace_single_parts(privacy,
-          mime->mm_data.mm_message.mm_msg_mime);
+          mime->mm_data.mm_message.mm_msg_mime, reencode);
       if (r != MAIL_NO_ERROR) {
         res = r;
         goto err;
@@ -364,7 +381,7 @@ static int recursive_replace_single_parts(struct mailprivacy * privacy,
 */
 
 int mailprivacy_get_mime(struct mailprivacy * privacy,
-    int check_privacy,
+    int check_privacy, int reencode,
     char * content, size_t content_len,
     struct mailmime ** result_mime)
 {
@@ -422,7 +439,7 @@ int mailprivacy_get_mime(struct mailprivacy * privacy,
   */
   mailprivacy_recursive_unregister_mime(privacy, mime);
 
-  r = recursive_replace_single_parts(privacy, mime);
+  r = recursive_replace_single_parts(privacy, mime, reencode);
   if (r != MAIL_NO_ERROR) {
     res = r;
     goto clear_mime;
@@ -681,7 +698,7 @@ int mailprivacy_fetch_mime_body_to_file(struct mailprivacy * privacy,
 
 
 int mailprivacy_get_part_from_file(struct mailprivacy * privacy,
-    int check_security, char * filename,
+    int check_security, int reencode, char * filename,
     struct mailmime ** result_mime)
 {
   int fd;
@@ -709,8 +726,9 @@ int mailprivacy_get_part_from_file(struct mailprivacy * privacy,
     goto close;
   }
   
+  mime = NULL;
   /* check recursive parts if privacy is set */
-  r = mailprivacy_get_mime(privacy, check_security,
+  r = mailprivacy_get_mime(privacy, check_security, reencode,
       mapping, stat_info.st_size, &mime);
   if (r != MAIL_NO_ERROR) {
     res =  r;
@@ -755,8 +773,14 @@ int mail_quote_filename(char * result, size_t size, char * path)
   remaining = size;
 
   for(p = path ; * p != '\0' ; p ++) {
-
-    if (isalpha(* p) || isdigit(* p) || (* p == '/')) {
+    int quote_not_needed;
+    
+#if 0
+    quote_not_needed = (isalpha(* p) || isdigit(* p) || (* p == '/'));
+#else
+    quote_not_needed = (* p != '\\') && (* p != '\'') && (* p != '\"');
+#endif
+    if (quote_not_needed) {
       if (remaining > 0) {
         * result_p = * p;
         result_p ++; 
