@@ -30,9 +30,14 @@
  */
 
 /*
- * $Id: mailimap.c,v 1.30 2004/11/21 21:53:36 hoa Exp $
+ * $Id: mailimap.c,v 1.31 2005/07/16 17:55:56 hoa Exp $
  */
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include "mailimap.h"
 #include "mailimap_parser.h"
 #include "mailimap_sender.h"
@@ -42,6 +47,13 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef USE_SASL
+#include <sasl/sasl.h>
+#include <sasl/saslutil.h>
+#endif
+
+#include "mailsasl.h"
+
 #ifdef DEBUG
 #include "mailimap_print.h"
 #endif
@@ -578,7 +590,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
       session->imap_stream_buffer,
       &index, &cont_req,
       session->imap_progr_rate, session->imap_progr_fun);
-  if (r == MAILIMAP_NO_ERROR) 
+  if (r == MAILIMAP_NO_ERROR)
     mailimap_continue_req_free(cont_req);
 
   if (r == MAILIMAP_ERROR_PARSE) {
@@ -622,18 +634,6 @@ int mailimap_append(mailimap * session, const char * mailbox,
   }
 }
 
-/*
-gboolean mailimap_authenticate(mailimap * session,
-			       gchar * auth_type)
-{
-}
-
-gboolean mailimap_authenticate_resp_send(mailimap * session,
-					 gchar * base64)
-{
-}
-*/
-
 int mailimap_noop(mailimap * session)
 {
   struct mailimap_response * response;
@@ -1446,6 +1446,309 @@ int mailimap_login(mailimap * session,
   }
 }
 
+#ifdef USE_SASL
+static int sasl_getsimple(void * context, int id,
+    const char ** result, unsigned * len)
+{
+  mailimap * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_USER:
+    if (result != NULL)
+      * result = session->imap_sasl.sasl_login;
+    if (len != NULL)
+      * len = strlen(session->imap_sasl.sasl_login);
+    return SASL_OK;
+    
+  case SASL_CB_AUTHNAME:
+    if (result != NULL)
+      * result = session->imap_sasl.sasl_auth_name;
+    if (len != NULL)
+      * len = strlen(session->imap_sasl.sasl_auth_name);
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+
+static int sasl_getsecret(sasl_conn_t * conn, void * context, int id,
+    sasl_secret_t ** psecret)
+{
+  mailimap * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_PASS:
+    if (psecret != NULL)
+      * psecret = session->imap_sasl.sasl_secret;
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+
+static int sasl_getrealm(void * context, int id,
+    const char ** availrealms,
+    const char ** result)
+{
+  mailimap * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_GETREALM:
+    if (result != NULL)
+      * result = session->imap_sasl.sasl_realm;
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+#endif
+
+int mailimap_authenticate(mailimap * session, const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+#ifdef USE_SASL
+  struct mailimap_response * response;
+  int r;
+  int error_code;
+  size_t index;
+  struct mailimap_cont_req_or_resp_data * cont_or_resp_data;
+  sasl_callback_t sasl_callback[5];
+  const char * sasl_out;
+  unsigned sasl_out_len;
+  const char * mechusing;
+  sasl_secret_t * secret;
+  int res;
+  size_t len;
+  
+  if (session->imap_state != MAILIMAP_STATE_NON_AUTHENTICATED) {
+    res = MAILIMAP_ERROR_BAD_STATE;
+    goto err;
+  }
+  
+  sasl_callback[0].id = SASL_CB_GETREALM;
+  sasl_callback[0].proc =  sasl_getrealm;
+  sasl_callback[0].context = session;
+  sasl_callback[1].id = SASL_CB_USER;
+  sasl_callback[1].proc =  sasl_getsimple;
+  sasl_callback[1].context = session;
+  sasl_callback[2].id = SASL_CB_AUTHNAME;
+  sasl_callback[2].proc =  sasl_getsimple;
+  sasl_callback[2].context = session; 
+  sasl_callback[3].id = SASL_CB_PASS;
+  sasl_callback[3].proc =  sasl_getsecret;
+  sasl_callback[3].context = session;
+  sasl_callback[4].id = SASL_CB_LIST_END;
+  sasl_callback[4].proc =  NULL;
+  sasl_callback[4].context = NULL;
+
+  len = strlen(password);
+  secret = malloc(sizeof(* secret) + len);
+  if (secret == NULL) {
+    res = MAILIMAP_ERROR_MEMORY;
+    goto err;
+  }
+  secret->len = len;
+  memcpy(secret->data, password, len + 1);
+
+  session->imap_sasl.sasl_server_fqdn = server_fqdn;
+  session->imap_sasl.sasl_login = login;
+  session->imap_sasl.sasl_auth_name = auth_name;
+  session->imap_sasl.sasl_password = password;
+  session->imap_sasl.sasl_realm = realm;
+  session->imap_sasl.sasl_secret = secret;
+  
+  /* init SASL */
+  mailsasl_ref();
+  
+  r = sasl_client_new("imap", server_fqdn,
+      local_ip_port, remote_ip_port, sasl_callback, 0,
+      (sasl_conn_t **) &session->imap_sasl.sasl_conn);
+  if (r != SASL_OK) {
+    res = MAILIMAP_ERROR_LOGIN;
+    goto free_secret;
+  }
+  
+  r = sasl_client_start(session->imap_sasl.sasl_conn,
+      auth_type, NULL, &sasl_out, &sasl_out_len, &mechusing);
+  if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
+    res = MAILIMAP_ERROR_LOGIN;
+    goto free_secret;
+  }
+  
+  r = send_current_tag(session);
+  if (r != MAILIMAP_NO_ERROR) {
+    res = r;
+    goto free_secret;
+  }
+
+  r = mailimap_authenticate_send(session->imap_stream, auth_type);
+  if (r != MAILIMAP_NO_ERROR) {
+    res = r;
+    goto free_secret;
+  }
+
+  r = mailimap_crlf_send(session->imap_stream);
+  if (r != MAILIMAP_NO_ERROR) {
+    res = r;
+    goto free_secret;
+  }
+
+  if (mailstream_flush(session->imap_stream) == -1) {
+    res = MAILIMAP_ERROR_STREAM;
+    goto free_secret;
+  }
+  
+  while (1) {
+    struct mailimap_continue_req * cont_req;
+    char * response;
+    int got_response;
+    char * encoded;
+    unsigned int encoded_len;
+    unsigned int max_encoded;
+    
+    if (read_line(session) == NULL) {
+      res = MAILIMAP_ERROR_STREAM;
+      goto free_secret;
+    }
+    
+    index = 0;
+    
+    r = mailimap_continue_req_parse(session->imap_stream,
+        session->imap_stream_buffer,
+        &index, &cont_req,
+        session->imap_progr_rate, session->imap_progr_fun);
+    if (r != MAILIMAP_NO_ERROR)
+      break;
+    
+    got_response = 1;
+    if (cont_req->cr_type == MAILIMAP_CONTINUE_REQ_BASE64) {
+      response = cont_req->cr_data.cr_base64;
+      if (* response == '\0')
+        got_response = 0;
+    }
+    else {
+      response = "";
+      got_response = 0;
+    }
+    
+    if (got_response) {
+      size_t response_len;
+      char * decoded;
+      unsigned int decoded_len;
+      unsigned int max_decoded;
+      
+      response_len = strlen(response);
+      max_decoded = response_len * 3 / 4;
+      decoded = malloc(max_decoded + 1);
+      if (decoded == NULL) {
+        mailimap_continue_req_free(cont_req);
+        res = MAILIMAP_ERROR_MEMORY;
+        goto free_secret;
+      }
+      
+      r = sasl_decode64(response, response_len,
+          decoded, max_decoded + 1, &decoded_len);
+      
+      mailimap_continue_req_free(cont_req);
+      
+      if (r != SASL_OK) {
+        free(decoded);
+        res = MAILIMAP_ERROR_MEMORY;
+        goto free_secret;
+      }
+      
+      r = sasl_client_step(session->imap_sasl.sasl_conn,
+          decoded, decoded_len, NULL, &sasl_out, &sasl_out_len);
+      
+      free(decoded);
+      
+      if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
+        res = MAILIMAP_ERROR_LOGIN;
+        goto free_secret;
+      }
+    }
+    else {
+      mailimap_continue_req_free(cont_req);
+    }
+    
+    max_encoded = ((sasl_out_len + 2) / 3) * 4;
+    encoded = malloc(max_encoded + 1);
+    if (encoded == NULL) {
+      res = MAILIMAP_ERROR_MEMORY;
+      goto free_secret;
+    }
+    
+    r = sasl_encode64(sasl_out, sasl_out_len,
+        encoded, max_encoded + 1, &encoded_len);
+    if (r != SASL_OK) {
+      free(encoded);
+      res = MAILIMAP_ERROR_MEMORY;
+      goto free_secret;
+    }
+    
+    r = mailimap_token_send(session->imap_stream, encoded);
+    
+    free(encoded);
+    
+    if (r != MAILIMAP_NO_ERROR) {
+      res = r;
+      goto free_secret;
+    }
+    
+    r = mailimap_crlf_send(session->imap_stream);
+    if (r != MAILIMAP_NO_ERROR) {
+      res = r;
+      goto free_secret;
+    }
+    
+    if (mailstream_flush(session->imap_stream) == -1) {
+      res = MAILIMAP_ERROR_STREAM;
+      goto free_secret;
+    }
+  }
+  
+  free(session->imap_sasl.sasl_secret);
+  
+  r = parse_response(session, &response);
+  if (r != MAILIMAP_NO_ERROR) {
+    res = r;
+    goto err;
+  }
+  
+  error_code = response->rsp_resp_done->rsp_data.rsp_tagged->rsp_cond_state->rsp_type;
+  
+  mailimap_response_free(response);
+  
+  switch (error_code) {
+  case MAILIMAP_RESP_COND_STATE_OK:
+    session->imap_state = MAILIMAP_STATE_AUTHENTICATED;
+    return MAILIMAP_NO_ERROR;
+    
+  default:
+    res = MAILIMAP_ERROR_LOGIN;
+    goto err;
+  }
+  
+ free_secret:
+  free(session->imap_sasl.sasl_secret);
+ err:
+  return res;
+#else
+  return MAILIMAP_ERROR_LOGIN;
+#endif
+}
+
+
 int mailimap_lsub(mailimap * session, const char * mb,
     const char * list_mb, clist ** result)
 {
@@ -2135,6 +2438,10 @@ mailimap * mailimap_new(size_t imap_progr_rate,
   f->imap_response_info = NULL;
   f->imap_connection_info = NULL;
 
+#ifdef USE_SASL
+  f->imap_sasl.sasl_conn = NULL;
+#endif
+  
   return f;
 
  free_stream_buffer:
@@ -2147,6 +2454,13 @@ mailimap * mailimap_new(size_t imap_progr_rate,
 
 void mailimap_free(mailimap * session)
 {
+#ifdef USE_SASL
+  if (session->imap_sasl.sasl_conn != NULL) {
+    sasl_dispose((sasl_conn_t **) &session->imap_sasl.sasl_conn);
+    mailsasl_unref();
+  }
+#endif
+  
   if (session->imap_stream)
     mailimap_logout(session);
 
