@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: mailimf_types.h,v 1.30 2004/11/21 21:53:37 hoa Exp $
+ * $Id: mailimf_types.h,v 1.33 2005/06/01 20:23:16 hoa Exp $
  */
 
 #ifndef MAILIMF_TYPES_H
@@ -42,6 +42,7 @@
 extern "C" {
 #endif
 
+#include <libetpan/libetpan-config.h>
 #include <libetpan/clist.h>
 #include <sys/types.h>
 
@@ -85,10 +86,12 @@ struct mailimf_date_time {
   int dt_zone;
 };
 
+LIBETPAN_EXPORT
 struct mailimf_date_time *
 mailimf_date_time_new(int dt_day, int dt_month, int dt_year,
     int dt_hour, int dt_min, int dt_sec, int dt_zone);
 
+LIBETPAN_EXPORT
 void mailimf_date_time_free(struct mailimf_date_time * date_time);
 
 
@@ -121,11 +124,12 @@ struct mailimf_address {
   } ad_data;
 };
 
-
+LIBETPAN_EXPORT
 struct mailimf_address *
 mailimf_address_new(int ad_type, struct mailimf_mailbox * ad_mailbox,
     struct mailimf_group * ad_group);
 
+LIBETPAN_EXPORT
 void mailimf_address_free(struct mailimf_address * address);
 
 
@@ -146,9 +150,11 @@ struct mailimf_mailbox {
   char * mb_addr_spec;    /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_mailbox *
 mailimf_mailbox_new(char * mb_display_name, char * mb_addr_spec);
 
+LIBETPAN_EXPORT
 void mailimf_mailbox_free(struct mailimf_mailbox * mailbox);
 
 
@@ -169,10 +175,12 @@ struct mailimf_group {
   struct mailimf_mailbox_list * grp_mb_list; /* can be NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_group *
 mailimf_group_new(char * grp_display_name,
     struct mailimf_mailbox_list * grp_mb_list);
 
+LIBETPAN_EXPORT
 void mailimf_group_free(struct mailimf_group * group);
 
 
@@ -187,9 +195,11 @@ struct mailimf_mailbox_list {
   clist * mb_list; /* list of (struct mailimf_mailbox *), != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_mailbox_list *
 mailimf_mailbox_list_new(clist * mb_list);
 
+LIBETPAN_EXPORT
 void mailimf_mailbox_list_free(struct mailimf_mailbox_list * mb_list);
 
 
@@ -204,9 +214,11 @@ struct mailimf_address_list {
   clist * ad_list; /* list of (struct mailimf_address *), != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_address_list *
 mailimf_address_list_new(clist * ad_list);
 
+LIBETPAN_EXPORT
 void mailimf_address_list_free(struct mailimf_address_list * addr_list);
 
 
@@ -227,8 +239,10 @@ struct mailimf_body {
   size_t bd_size;
 };
 
+LIBETPAN_EXPORT
 struct mailimf_body * mailimf_body_new(const char * bd_text, size_t bd_size);
 
+LIBETPAN_EXPORT
 void mailimf_body_free(struct mailimf_body * body);
 
 
@@ -247,10 +261,12 @@ struct mailimf_message {
   struct mailimf_body * msg_body;     /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_message *
 mailimf_message_new(struct mailimf_fields * msg_fields,
     struct mailimf_body * msg_body);
 
+LIBETPAN_EXPORT
 void mailimf_message_free(struct mailimf_message * message);
 
 
@@ -266,8 +282,10 @@ struct mailimf_fields {
   clist * fld_list; /* list of (struct mailimf_field *), != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_fields * mailimf_fields_new(clist * fld_list);
 
+LIBETPAN_EXPORT
 void mailimf_fields_free(struct mailimf_fields * fields);
 
 
@@ -383,6 +401,7 @@ struct mailimf_field {
   } fld_data;
 };
 
+LIBETPAN_EXPORT
 struct mailimf_field *
 mailimf_field_new(int fld_type,
     struct mailimf_return * fld_return_path,
@@ -408,6 +427,7 @@ mailimf_field_new(int fld_type,
     struct mailimf_keywords * fld_keywords,
     struct mailimf_optional_field * fld_optional_field);
 
+LIBETPAN_EXPORT
 void mailimf_field_free(struct mailimf_field * field);
 
 
@@ -422,9 +442,11 @@ struct mailimf_orig_date {
   struct mailimf_date_time * dt_date_time; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_orig_date * mailimf_orig_date_new(struct mailimf_date_time *
     dt_date_time);
 
+LIBETPAN_EXPORT
 void mailimf_orig_date_free(struct mailimf_orig_date * orig_date);
 
 
@@ -440,9 +462,11 @@ struct mailimf_from {
   struct mailimf_mailbox_list * frm_mb_list; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_from *
 mailimf_from_new(struct mailimf_mailbox_list * frm_mb_list);
 
+LIBETPAN_EXPORT
 void mailimf_from_free(struct mailimf_from * from);
 
 
@@ -457,8 +481,10 @@ struct mailimf_sender {
   struct mailimf_mailbox * snd_mb; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_sender * mailimf_sender_new(struct mailimf_mailbox * snd_mb);
 
+LIBETPAN_EXPORT
 void mailimf_sender_free(struct mailimf_sender * sender);
 
 
@@ -474,9 +500,11 @@ struct mailimf_reply_to {
   struct mailimf_address_list * rt_addr_list; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_reply_to *
 mailimf_reply_to_new(struct mailimf_address_list * rt_addr_list);
 
+LIBETPAN_EXPORT
 void mailimf_reply_to_free(struct mailimf_reply_to * reply_to);
 
 
@@ -492,8 +520,10 @@ struct mailimf_to {
   struct mailimf_address_list * to_addr_list; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_to * mailimf_to_new(struct mailimf_address_list * to_addr_list);
 
+LIBETPAN_EXPORT
 void mailimf_to_free(struct mailimf_to * to);
 
 
@@ -509,8 +539,10 @@ struct mailimf_cc {
   struct mailimf_address_list * cc_addr_list; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_cc * mailimf_cc_new(struct mailimf_address_list * cc_addr_list);
 
+LIBETPAN_EXPORT
 void mailimf_cc_free(struct mailimf_cc * cc);
 
 
@@ -526,9 +558,11 @@ struct mailimf_bcc {
   struct mailimf_address_list * bcc_addr_list; /* can be NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_bcc *
 mailimf_bcc_new(struct mailimf_address_list * bcc_addr_list);
 
+LIBETPAN_EXPORT
 void mailimf_bcc_free(struct mailimf_bcc * bcc);
 
 
@@ -543,8 +577,10 @@ struct mailimf_message_id {
   char * mid_value; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_message_id * mailimf_message_id_new(char * mid_value);
 
+LIBETPAN_EXPORT
 void mailimf_message_id_free(struct mailimf_message_id * message_id);
 
 
@@ -560,8 +596,10 @@ struct mailimf_in_reply_to {
   clist * mid_list; /* list of (char *), != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_in_reply_to * mailimf_in_reply_to_new(clist * mid_list);
 
+LIBETPAN_EXPORT
 void mailimf_in_reply_to_free(struct mailimf_in_reply_to * in_reply_to);
 
 
@@ -577,8 +615,10 @@ struct mailimf_references {
        /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_references * mailimf_references_new(clist * mid_list);
 
+LIBETPAN_EXPORT
 void mailimf_references_free(struct mailimf_references * references);
 
 
@@ -593,8 +633,10 @@ struct mailimf_subject {
   char * sbj_value; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_subject * mailimf_subject_new(char * sbj_value);
 
+LIBETPAN_EXPORT
 void mailimf_subject_free(struct mailimf_subject * subject);
 
 
@@ -608,8 +650,10 @@ struct mailimf_comments {
   char * cm_value; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_comments * mailimf_comments_new(char * cm_value);
 
+LIBETPAN_EXPORT
 void mailimf_comments_free(struct mailimf_comments * comments);
 
 
@@ -623,8 +667,10 @@ struct mailimf_keywords {
   clist * kw_list; /* list of (char *), != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_keywords * mailimf_keywords_new(clist * kw_list);
 
+LIBETPAN_EXPORT
 void mailimf_keywords_free(struct mailimf_keywords * keywords);
 
 
@@ -638,9 +684,11 @@ struct mailimf_return {
   struct mailimf_path * ret_path; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_return *
 mailimf_return_new(struct mailimf_path * ret_path);
 
+LIBETPAN_EXPORT
 void mailimf_return_free(struct mailimf_return * return_path);
 
 
@@ -654,8 +702,10 @@ struct mailimf_path {
   char * pt_addr_spec; /* can be NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_path * mailimf_path_new(char * pt_addr_spec);
 
+LIBETPAN_EXPORT
 void mailimf_path_free(struct mailimf_path * path);
 
 
@@ -672,9 +722,11 @@ struct mailimf_optional_field {
   char * fld_value; /* != NULL */
 };
 
+LIBETPAN_EXPORT
 struct mailimf_optional_field *
 mailimf_optional_field_new(char * fld_name, char * fld_value);
 
+LIBETPAN_EXPORT
 void mailimf_optional_field_free(struct mailimf_optional_field * opt_field);
 
 
