@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildir.c,v 1.13 2005/06/01 12:22:18 smarinier Exp $
+ * $Id: maildir.c,v 1.14 2005/12/20 17:56:11 hoa Exp $
  */
 
 #include "maildir.h"
@@ -727,6 +727,7 @@ int maildir_message_change_flags(struct maildir * md,
   char flag_str[5];
   size_t i;
   int res;
+  char * dup_filename;
 
   key.data = (void *) uid;
   key.len = strlen(uid);
@@ -795,6 +796,14 @@ int maildir_message_change_flags(struct maildir * md,
     }
   }
   
+  dup_filename = strdup(libetpan_basename(new_filename));
+  if (dup_filename != NULL) {
+    free(msg->msg_filename);
+    msg->msg_filename = dup_filename;
+  }
+  
+  msg->msg_flags = new_flags;
+  
   return MAILDIR_NO_ERROR;
   
  err:
