@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmbox.c,v 1.41 2005/06/01 16:04:46 hoa Exp $
+ * $Id: mailmbox.c,v 1.42 2005/08/13 14:52:23 hoa Exp $
  */
 
 #include "mailmbox.h"
@@ -58,11 +58,17 @@
 #include "mailmbox_parse.h"
 #include "maillock.h"
 
+#if 0
+#define CRLF_BADNESS
+#endif
+
 /*
   http://www.qmail.org/qmail-manual-html/man5/mbox.html
   RFC 2076
 */
 
+/* used only in case the directory which contains the original file
+   is not writable */
 #define TMPDIR "/tmp"
 
 /* mbox is a file with a corresponding filename */
@@ -448,7 +454,11 @@ static size_t get_fixed_message_size(const char * message, size_t size,
   if (!force_no_uid) {
     /* UID header */
     
+#ifdef CRLF_BADNESS
     fixed_size += strlen(UID_HEADER " \r\n");
+#else
+    fixed_size += strlen(UID_HEADER " \n");
+#endif
     
     tmp_uid = uid;
     while (tmp_uid >= 10) {
@@ -560,7 +570,11 @@ static char * write_fixed_message(char * str,
     
     memcpy(str, UID_HEADER " ", strlen(UID_HEADER " "));
     str += strlen(UID_HEADER " ");
+#ifdef CRLF_BADNESS
     numlen = snprintf(str, 20, "%i\r\n", uid);
+#else
+    numlen = snprintf(str, 20, "%i\n", uid);
+#endif
     str += numlen;
   }
 
@@ -611,7 +625,11 @@ mailmbox_append_message_list_no_lock(struct mailmbox_folder * folder,
   date = time(NULL);
   from_size = strlen(DEFAULT_FROM_LINE);
   if (localtime_r(&date, &time_info) != NULL)
+#ifdef CRLF_BADNESS
+    from_size = strftime(from_line, MAX_FROM_LINE_SIZE, "From - %c\r\n", &time_info);
+#else
     from_size = strftime(from_line, MAX_FROM_LINE_SIZE, "From - %c\n", &time_info);
+#endif
 
   maxuid = /* */ folder->mb_max_uid;
 
@@ -624,7 +642,11 @@ mailmbox_append_message_list_no_lock(struct mailmbox_folder * folder,
     extra_size += get_fixed_message_size(info->ai_message, info->ai_size,
         folder->mb_max_uid + i + 1,
         folder->mb_no_uid);
+#ifdef CRLF_BADNESS
     extra_size += 2; /* CR LF */
+#else
+    extra_size += 1; /* CR LF */
+#endif
     
     info->ai_uid = folder->mb_max_uid + i + 1;
   }
@@ -636,9 +658,11 @@ mailmbox_append_message_list_no_lock(struct mailmbox_folder * folder,
       crlf_count ++;
       left --;
     }
+#ifdef CRLF_BADNESS
     else if (folder->mb_mapping[left - 1] == '\r') {
       left --;
     }
+#endif
     else
       break;
 
@@ -651,7 +675,12 @@ mailmbox_append_message_list_no_lock(struct mailmbox_folder * folder,
 
   if (old_size != 0) {
     if (crlf_count != 2)
+#ifdef CRLF_BADNESS
       extra_size += (2 - crlf_count) * 2;
+#else
+      /* Need the number of LFs, not CRLFs */
+      extra_size += (2 - crlf_count) * 1;
+#endif
   }
 
   r = ftruncate(folder->mb_fd, extra_size + old_size);
@@ -671,8 +700,10 @@ mailmbox_append_message_list_no_lock(struct mailmbox_folder * folder,
 
   if (old_size != 0) {
     for(i = 0 ; i < 2 - crlf_count ; i ++) {
+#ifdef CRLF_BADNESS
       * str = '\r';
       str ++;
+#endif
       * str = '\n';
       str ++;
     }
@@ -691,8 +722,10 @@ mailmbox_append_message_list_no_lock(struct mailmbox_folder * folder,
         folder->mb_max_uid + i + 1,
         folder->mb_no_uid);
 
+#ifdef CRLF_BADNESS
     * str = '\r';
     str ++;
+#endif
     * str = '\n';
     str ++;
   }
@@ -1148,7 +1181,11 @@ static int mailmbox_expunge_to_file_no_lock(char * dest_filename, int dest_fd,
 	if (!info->msg_written_uid) {
 	  uint32_t uid;
 	  
+#ifdef CRLF_BADNESS
 	  size += strlen(UID_HEADER " \r\n");
+#else
+	  size += strlen(UID_HEADER " \n");
+#endif
 	  
 	  uid = info->msg_uid;
 	  while (uid >= 10) {
@@ -1190,8 +1227,13 @@ static int mailmbox_expunge_to_file_no_lock(char * dest_filename, int dest_fd,
 	  
 	  memcpy(dest + cur_offset, UID_HEADER " ", strlen(UID_HEADER " "));
 	  cur_offset += strlen(UID_HEADER " ");
+#ifdef CRLF_BADNESS
 	  numlen = snprintf(dest + cur_offset, size - cur_offset,
 			    "%i\r\n", info->msg_uid);
+#else
+	  numlen = snprintf(dest + cur_offset, size - cur_offset,
+			    "%i\n", info->msg_uid);
+#endif
 	  cur_offset += numlen;
 	}
       }
