@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmh.c,v 1.29 2004/12/12 12:07:17 hoa Exp $
+ * $Id: mailmh.c,v 1.31 2005/06/13 07:24:07 hoa Exp $
  */
 
 #include "mailmh.h"
@@ -50,11 +50,15 @@ sys     0m0.110s
 
 */
 
-#include <dirent.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <dirent.h>
+#	include <unistd.h>
+#	include <sys/mman.h>
+#endif
 #include <sys/stat.h>
 #include <errno.h>
-#include <unistd.h>
-#include <sys/mman.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -496,7 +500,11 @@ int mailmh_folder_add_subfolder(struct mailmh_folder * parent,
   strcat(foldername, MAIL_DIR_SEPARATOR_S);
   strcat(foldername, name);
 
+#ifdef WIN32
+  r = mkdir(foldername);
+#else
   r = mkdir(foldername, 0700);
+#endif
   free(foldername);
 
   if (r < 0)
@@ -621,11 +629,19 @@ static int mailmh_folder_alloc_msg(struct mailmh_folder * folder,
   k = 0;
   while (k < MAX_TRY_ALLOC) {
     snprintf(new_filename, len, "%s%c%lu", folder->fl_filename,
-	     MAIL_DIR_SEPARATOR, (unsigned long) (max + k));
-
+        MAIL_DIR_SEPARATOR, (unsigned long) (max + k));
+    
+/* SEB */
+#ifdef WIN32
+	if (rename( filename, new_filename) == 0) {
+		got_file = 1;
+	}
+#else
     if (link(filename, new_filename) == 0) {
       unlink(filename);
+      got_file = 1;
     }
+#endif /* WIN32 */
     else if (errno == EXDEV) {
       free(filename);
       return MAILMH_ERROR_FOLDER;
