@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime.c,v 1.24 2004/11/21 21:53:38 hoa Exp $
+ * $Id: mailmime.c,v 1.26 2005/06/01 16:04:46 hoa Exp $
  */
 
 #include "mailmime.h"
@@ -192,6 +192,7 @@ x  content := "Content-Type" ":" type "/" subtype
              ; is ALWAYS case-insensitive.
 */
 
+LIBETPAN_EXPORT
 int mailmime_content_parse(const char * message, size_t length,
 			   size_t * index,
 			   struct mailmime_content ** result)
@@ -208,6 +209,7 @@ int mailmime_content_parse(const char * message, size_t length,
 
   mailimf_cfws_parse(message, length, &cur_token);
 
+  type = NULL;
   r = mailmime_type_parse(message, length, &cur_token, &type);
   if (r != MAILIMF_NO_ERROR) {
     res = r;
@@ -322,6 +324,7 @@ static int is_text(char ch)
   return TRUE;
 }
 
+LIBETPAN_EXPORT
 int mailmime_description_parse(const char * message, size_t length,
 			       size_t * index,
 			       char ** result)
@@ -422,6 +425,7 @@ mailmime_discrete_type_parse(const char * message, size_t length,
 x  encoding := "Content-Transfer-Encoding" ":" mechanism
 */
 
+LIBETPAN_EXPORT
 int mailmime_encoding_parse(const char * message, size_t length,
 			    size_t * index,
 			    struct mailmime_mechanism ** result)
@@ -504,6 +508,7 @@ static int guess_field_type(char * name)
   }
 }
 
+LIBETPAN_EXPORT
 int
 mailmime_field_parse(struct mailimf_optional_field * field,
 		     struct mailmime_field ** result)
@@ -628,6 +633,7 @@ mailmime_field_parse(struct mailimf_optional_field * field,
 x  extension-token := ietf-token / x-token
 */
 
+LIBETPAN_EXPORT
 int
 mailmime_extension_token_parse(const char * message, size_t length,
 			       size_t * index, char ** result)
@@ -659,6 +665,7 @@ x  ietf-token := <An extension token defined by a
 x  id := "Content-ID" ":" msg-id
 */
 
+LIBETPAN_EXPORT
 int mailmime_id_parse(const char * message, size_t length,
 		      size_t * index, char ** result)
 {
@@ -780,6 +787,7 @@ x  MIME-part-headers := entity-headers
 */
 
 #if 0
+LIBETPAN_EXPORT
 int
 mailmime_unparsed_fields_parse(struct mailimf_unparsed_fields *
 			       fields,
@@ -842,6 +850,7 @@ mailmime_unparsed_fields_parse(struct mailimf_unparsed_fields *
 }
 #endif
 
+LIBETPAN_EXPORT
 int
 mailmime_fields_parse(struct mailimf_fields *
 		      fields,
@@ -914,6 +923,7 @@ mailmime_fields_parse(struct mailimf_fields *
 x  parameter := attribute "=" value
 */
 
+LIBETPAN_EXPORT
 int mailmime_parameter_parse(const char * message, size_t length,
 			     size_t * index,
 			     struct mailmime_parameter ** result)
@@ -1229,6 +1239,7 @@ static int mailmime_type_parse(const char * message, size_t length,
 x  value := token / quoted-string
 */
 
+LIBETPAN_EXPORT
 int mailmime_value_parse(const char * message, size_t length,
 			 size_t * index, char ** result)
 {
@@ -1249,6 +1260,7 @@ int mailmime_value_parse(const char * message, size_t length,
 x  version := "MIME-Version" ":" 1*DIGIT "." 1*DIGIT
 */
 
+LIBETPAN_EXPORT
 int mailmime_version_parse(const char * message, size_t length,
 			   size_t * index,
 			   uint32_t * result)
@@ -1333,6 +1345,7 @@ static gboolean mailmime_x_token_parse(gconst char * message, guint32 length,
 */
 
 
+LIBETPAN_EXPORT
 int mailmime_language_parse(const char * message, size_t length,
 			    size_t * index,
 			    struct mailmime_language ** result)
