@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_decode.c,v 1.24 2004/12/12 12:07:18 hoa Exp $
+ * $Id: mailmime_decode.c,v 1.26 2005/06/01 16:04:46 hoa Exp $
  */
 
 /*
@@ -41,8 +41,12 @@
 #include "mailmime_decode.h"
 
 #include <ctype.h>
-#include <unistd.h>
-#include <sys/mman.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
+#if HAVE_SYS_MMAN_H
+#	include <sys/mman.h>
+#endif
 #include <string.h>
 #include <stdlib.h>
 
@@ -91,6 +95,7 @@ enum {
   TYPE_ENCODED_WORD,
 };
 
+LIBETPAN_EXPORT
 int mailmime_encoded_phrase_parse(const char * default_fromcode,
     const char * message, size_t length,
     size_t * index, const char * tocode,
@@ -120,6 +125,7 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
 
   while (1) {
 
+    word = NULL;
     r = mailmime_encoded_word_parse(message, length, &cur_token, &word);
     if (r == MAILIMF_NO_ERROR) {
       if (!first) {
@@ -171,6 +177,7 @@ int mailmime_encoded_phrase_parse(const char * default_fromcode,
     if (r == MAILIMF_ERROR_PARSE) {
       char * raw_word;
 
+      raw_word = NULL;
       r = mailmime_non_encoded_word_parse(message, length,
 					  &cur_token, &raw_word);
       if (r == MAILIMF_NO_ERROR) {
