@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_types.c,v 1.18 2004/11/21 21:53:39 hoa Exp $
+ * $Id: mailmime_types.c,v 1.19 2005/01/29 15:40:24 hoa Exp $
  */
 
 #include "mailmime_types.h"
@@ -458,10 +458,10 @@ struct mailmime * mailmime_new(int mm_type,
 
 void mailmime_free(struct mailmime * mime)
 {
-  if (mime->mm_body != NULL)
-    mailmime_data_free(mime->mm_body);
   switch (mime->mm_type) {
   case MAILMIME_SINGLE:
+    if ((mime->mm_body == NULL) && (mime->mm_data.mm_single != NULL))
+      mailmime_data_free(mime->mm_data.mm_single);
     /* do nothing */
     break;
     
@@ -483,6 +483,9 @@ void mailmime_free(struct mailmime * mime)
     break;
     
   }
+  if (mime->mm_body != NULL)
+    mailmime_data_free(mime->mm_body);
+
   if (mime->mm_mime_fields != NULL)
     mailmime_fields_free(mime->mm_mime_fields);
   if (mime->mm_content_type != NULL)
