@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_types.h,v 1.29 2005/06/01 12:22:19 smarinier Exp $
+ * $Id: mailmime_types.h,v 1.31 2006/03/22 08:10:47 hoa Exp $
  */
 
 #ifndef MAILMIME_TYPES_H
@@ -42,7 +42,7 @@ extern "C" {
 #endif
 
 #ifndef LIBETPAN_CONFIG_H
-#	include "libetpan-config.h"
+#	include <libetpan/libetpan-config.h>
 #endif
 
 #if HAVE_INTTYPES_H
