@@ -30,19 +30,31 @@
  */
 
 /*
- * $Id: mailmime_write_generic.c,v 1.2 2004/11/21 21:53:39 hoa Exp $
+ * $Id: mailmime_write_generic.c,v 1.4 2005/06/01 20:23:17 hoa Exp $
  */
 
 #include "mailmime_write_generic.h"
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <sys/mman.h>
+#if HAVE_SYS_MMAN_H
+#	include <sys/mman.h>
+#endif
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#endif
 
 #include "mailimf_write_generic.h"
 #include "mailmime_content.h"
