@@ -30,16 +30,19 @@
  */
 
 /*
- * $Id: newsnntp.c,v 1.21 2004/11/21 21:53:39 hoa Exp $
+ * $Id: newsnntp.c,v 1.23 2005/06/01 16:04:46 hoa Exp $
  */
 
 #include "newsnntp.h"
 
 
-#include <unistd.h>
 #include <stdio.h>
-#include <netinet/in.h>
-#include <netdb.h>
+#ifndef _MSC_VER
+#	include <unistd.h>
+#	include <netinet/in.h>
+#	include <netdb.h>
+#endif
+
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
@@ -2424,8 +2427,10 @@ static clist * read_xover_resp_list(newsnntp * f)
 
     while (current) {
       char * val;
+      char * original_val;
 
-      val = strdup(clist_content(current));
+      original_val = clist_content(current);
+      val = strdup(original_val);
       if (val == NULL) {
 	clist_foreach(others, (clist_func) free, NULL);
 	clist_free(others);
