@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.c,v 1.22 2005/01/28 01:43:13 hoa Exp $
+ * $Id: mailpop3.c,v 1.25 2005/07/16 17:55:57 hoa Exp $
  */
 
 /*
@@ -49,6 +49,18 @@
 #include "mail.h"
 #include <stdlib.h>
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef USE_SASL
+#include <sasl/sasl.h>
+#include <sasl/saslutil.h>
+#endif
+
+#include "mailsasl.h"
+
 
 
 
@@ -207,7 +219,11 @@ mailpop3 * mailpop3_new(size_t progr_rate, progress_function * progr_fun)
   f->pop3_msg_tab = NULL;
   f->pop3_deleted_count = 0;
   f->pop3_state = POP3_STATE_DISCONNECTED;
-
+  
+#ifdef USE_SASL
+  f->pop3_sasl.sasl_conn = NULL;
+#endif
+  
   return f;
 
  free_stream_buffer:
@@ -222,6 +238,13 @@ mailpop3 * mailpop3_new(size_t progr_rate, progress_function * progr_fun)
 
 void mailpop3_free(mailpop3 * f)
 {
+#ifdef USE_SASL
+  if (f->pop3_sasl.sasl_conn != NULL) {
+    sasl_dispose((sasl_conn_t **) &f->pop3_sasl.sasl_conn);
+    mailsasl_unref();
+  }
+#endif
+  
   if (f->pop3_stream)
     mailpop3_quit(f);
 
@@ -247,6 +270,7 @@ void mailpop3_free(mailpop3 * f)
 
 #define RESPONSE_OK 0
 #define RESPONSE_ERR -1
+#define RESPONSE_AUTH_CONT 1
 
 static int send_command(mailpop3 * f, char * command);
 
@@ -361,7 +385,8 @@ int mailpop3_quit(mailpop3 * f)
   res = MAILPOP3_NO_ERROR;
 
  close:
-  mailstream_close(f->pop3_stream);
+  if (f->pop3_state != POP3_STATE_DISCONNECTED)
+    mailstream_close(f->pop3_stream);
 
   if (f->pop3_timestamp != NULL) {
     free(f->pop3_timestamp);
@@ -854,6 +879,7 @@ int mailpop3_capa(mailpop3 * f, clist ** result)
   if (r != RESPONSE_OK)
     return MAILPOP3_ERROR_CAPA_NOT_SUPPORTED;
   
+  capa_list = NULL;
   r = read_capa_resp(f, &capa_list);
   if (r != MAILPOP3_NO_ERROR)
     return r;
@@ -916,6 +942,7 @@ int mailpop3_stls(mailpop3 * f)
 
 #define RESP_OK_STR "+OK"
 #define RESP_ERR_STR "-ERR"
+#define RESP_AUTH_CONT_STR "+"
 
 
 static int parse_space(char ** line)
@@ -1008,6 +1035,33 @@ static int parse_response(mailpop3 * f, char * response)
 
 
 
+static int parse_auth(mailpop3 * f, char * response)
+{
+  char * msg;
+  
+  if (response == NULL) {
+    f->pop3_response = NULL;
+    return RESPONSE_ERR;
+  }
+
+  if (strncmp(response, RESP_AUTH_CONT_STR, strlen(RESP_AUTH_CONT_STR)) == 0) {
+
+    if (response[strlen(RESP_AUTH_CONT_STR)] == ' ')
+      msg = response + strlen(RESP_AUTH_CONT_STR) + 1;
+    else
+      msg = response + strlen(RESP_AUTH_CONT_STR);
+    
+    if (mmap_string_assign(f->pop3_response_buffer, msg))
+      f->pop3_response = f->pop3_response_buffer->str;
+    else
+      f->pop3_response = NULL;
+
+    return RESPONSE_AUTH_CONT;
+  }
+  else {
+    return parse_response(f, response);
+  }
+}
 
 
 static int read_list(mailpop3 * f, carray ** result)
@@ -1228,3 +1282,243 @@ static int send_command(mailpop3 * f, char * command)
 
   return 0;
 }
+
+
+
+#ifdef USE_SASL
+static int sasl_getsimple(void * context, int id,
+    const char ** result, unsigned * len)
+{
+  mailpop3 * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_USER:
+    if (result != NULL)
+      * result = session->pop3_sasl.sasl_login;
+    if (len != NULL)
+      * len = strlen(session->pop3_sasl.sasl_login);
+    return SASL_OK;
+    
+  case SASL_CB_AUTHNAME:
+    if (result != NULL)
+      * result = session->pop3_sasl.sasl_auth_name;
+    if (len != NULL)
+      * len = strlen(session->pop3_sasl.sasl_auth_name);
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+
+static int sasl_getsecret(sasl_conn_t * conn, void * context, int id,
+    sasl_secret_t ** psecret)
+{
+  mailpop3 * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_PASS:
+    if (psecret != NULL)
+      * psecret = session->pop3_sasl.sasl_secret;
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+
+static int sasl_getrealm(void * context, int id,
+    const char ** availrealms,
+    const char ** result)
+{
+  mailpop3 * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_GETREALM:
+    if (result != NULL)
+      * result = session->pop3_sasl.sasl_realm;
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+#endif
+
+int mailpop3_auth(mailpop3 * f, const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+#ifdef USE_SASL
+  int r;
+  char command[POP3_STRING_SIZE];
+  sasl_callback_t sasl_callback[5];
+  const char * sasl_out;
+  unsigned sasl_out_len;
+  const char * mechusing;
+  sasl_secret_t * secret;
+  int res;
+  size_t len;
+  char * encoded;
+  unsigned int encoded_len;
+  unsigned int max_encoded;
+  
+  sasl_callback[0].id = SASL_CB_GETREALM;
+  sasl_callback[0].proc =  sasl_getrealm;
+  sasl_callback[0].context = f;
+  sasl_callback[1].id = SASL_CB_USER;
+  sasl_callback[1].proc =  sasl_getsimple;
+  sasl_callback[1].context = f;
+  sasl_callback[2].id = SASL_CB_AUTHNAME;
+  sasl_callback[2].proc =  sasl_getsimple;
+  sasl_callback[2].context = f; 
+  sasl_callback[3].id = SASL_CB_PASS;
+  sasl_callback[3].proc =  sasl_getsecret;
+  sasl_callback[3].context = f;
+  sasl_callback[4].id = SASL_CB_LIST_END;
+  sasl_callback[4].proc =  NULL;
+  sasl_callback[4].context = NULL;
+  
+  len = strlen(password);
+  secret = malloc(sizeof(* secret) + len);
+  if (secret == NULL) {
+    res = MAILPOP3_ERROR_MEMORY;
+    goto err;
+  }
+  secret->len = len;
+  memcpy(secret->data, password, len + 1);
+  
+  f->pop3_sasl.sasl_server_fqdn = server_fqdn;
+  f->pop3_sasl.sasl_login = login;
+  f->pop3_sasl.sasl_auth_name = auth_name;
+  f->pop3_sasl.sasl_password = password;
+  f->pop3_sasl.sasl_realm = realm;
+  f->pop3_sasl.sasl_secret = secret;
+  
+  /* init SASL */
+  mailsasl_ref();
+  
+  r = sasl_client_new("pop", server_fqdn,
+      local_ip_port, remote_ip_port, sasl_callback, 0,
+      (sasl_conn_t **) &f->pop3_sasl.sasl_conn);
+  if (r != SASL_OK) {
+    res = MAILPOP3_ERROR_BAD_USER;
+    goto free_secret;
+  }
+  
+  r = sasl_client_start(f->pop3_sasl.sasl_conn,
+      auth_type, NULL, &sasl_out, &sasl_out_len, &mechusing);
+  if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
+    res = MAILPOP3_ERROR_BAD_USER;
+    goto free_secret;
+  }
+  
+  snprintf(command, POP3_STRING_SIZE, "AUTH %s\r\n", auth_type);
+  
+  r = send_command(f, command);
+  if (r == -1) {
+    res = MAILPOP3_ERROR_STREAM;
+    goto free_secret;
+  }
+  
+  while (1) {
+    char * response;
+    
+    response = read_line(f);
+    
+    r = parse_auth(f, response);
+    switch (r) {
+    case RESPONSE_OK:
+      free(f->pop3_sasl.sasl_secret);
+      return MAILPOP3_NO_ERROR;
+      
+    case RESPONSE_ERR:
+      res = MAILPOP3_ERROR_BAD_USER;
+      goto free_secret;
+    
+    case RESPONSE_AUTH_CONT:
+      {
+        size_t response_len;
+        char * decoded;
+        unsigned int decoded_len;
+        unsigned int max_decoded;
+        int got_response;
+        
+        got_response = 1;
+        if (* f->pop3_response == '\0')
+          got_response = 0;
+        
+        if (got_response) {
+          response_len = strlen(f->pop3_response);
+          max_decoded = response_len * 3 / 4;
+          decoded = malloc(max_decoded + 1);
+          if (decoded == NULL) {
+            res = MAILPOP3_ERROR_MEMORY;
+            goto free_secret;
+          }
+          
+          r = sasl_decode64(f->pop3_response, response_len,
+              decoded, max_decoded + 1, &decoded_len);
+          
+          if (r != SASL_OK) {
+            free(decoded);
+            res = MAILPOP3_ERROR_MEMORY;
+            goto free_secret;
+          }
+          
+          r = sasl_client_step(f->pop3_sasl.sasl_conn,
+              decoded, decoded_len, NULL, &sasl_out, &sasl_out_len);
+          
+          free(decoded);
+          
+          if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
+            res = MAILPOP3_ERROR_BAD_USER;
+            goto free_secret;
+          }
+        }
+        
+        max_encoded = ((sasl_out_len + 2) / 3) * 4;
+        encoded = malloc(max_encoded + 1);
+        if (encoded == NULL) {
+          res = MAILPOP3_ERROR_MEMORY;
+          goto free_secret;
+        }
+        
+        r = sasl_encode64(sasl_out, sasl_out_len,
+            encoded, max_encoded + 1, &encoded_len);
+        if (r != SASL_OK) {
+          free(encoded);
+          res = MAILPOP3_ERROR_MEMORY;
+          goto free_secret;
+        }
+        
+        snprintf(command, POP3_STRING_SIZE, "%s\r\n", encoded);
+        r = send_command(f, command);
+        
+        free(encoded);
+        
+        if (r == -1) {
+          res = MAILPOP3_ERROR_STREAM;
+          goto free_secret;
+        }
+      }
+      break;
+    }
+  }
+  
+  return MAILPOP3_NO_ERROR;
+  
+ free_secret:
+  free(f->pop3_sasl.sasl_secret);
+ err:
+  return res;
+#else
+  return MAILPOP3_ERROR_BAD_USER;
+#endif
+}
