@@ -32,7 +32,7 @@
  */
 
 /*
- * $Id: mailsmtp.c,v 1.20 2005/07/16 17:55:57 hoa Exp $
+ * $Id: mailsmtp.c,v 1.24 2006/01/04 11:08:35 hoa Exp $
  */
 
 #ifndef CONFIG_H
@@ -42,7 +42,6 @@
 
 #include "mailsmtp.h"
 #include "connect.h"
-#include "md5.h"
 #include "base64.h"
 #include "mail.h"
 
@@ -846,6 +845,12 @@ int mailsmtp_auth_type(mailsmtp * session,
 #endif
   int err;
   char command[SMTP_STRING_SIZE];
+  char hostname[SMTP_STRING_SIZE];
+  
+  err = gethostname(hostname, sizeof(hostname));
+  if (err < 0) {
+    return MAILSMTP_ERROR_MEMORY;
+  }
   
   if (session->auth == MAILSMTP_AUTH_NOT_CHECKED) 
     return MAILSMTP_ERROR_BAD_SEQUENCE_OF_COMMAND;
@@ -867,15 +872,15 @@ int mailsmtp_auth_type(mailsmtp * session,
     }
   case MAILSMTP_AUTH_PLAIN:
     return mailesmtp_auth_sasl(session, "PLAIN",
-        NULL, NULL, NULL, user, user, pass, NULL);
+        hostname, NULL, NULL, user, user, pass, NULL);
     
   case MAILSMTP_AUTH_CRAM_MD5:
     return mailesmtp_auth_sasl(session, "CRAM-MD5",
-        NULL, NULL, NULL, user, user, pass, NULL);
+        hostname, NULL, NULL, user, user, pass, NULL);
     
   case MAILSMTP_AUTH_DIGEST_MD5:
     return mailesmtp_auth_sasl(session, "DIGEST-MD5",
-        NULL, NULL, NULL, user, user, pass, NULL);
+        hostname, NULL, NULL, user, user, pass, NULL);
     
   default:
     return MAILSMTP_ERROR_NOT_IMPLEMENTED;
@@ -1306,3 +1311,35 @@ int mailesmtp_auth_sasl(mailsmtp * session, const char * auth_type,
 #endif
 }
 
+
+int mailsmtp_noop(mailsmtp * session)
+{
+  char command[SMTP_STRING_SIZE];
+  int r;
+
+  snprintf(command, SMTP_STRING_SIZE, "NOOP\r\n");
+  r = send_command(session, command);
+  if (r == -1)
+    return MAILSMTP_ERROR_STREAM;
+  r = read_response(session);
+  if (r == 0)
+    return MAILSMTP_ERROR_STREAM;
+  
+  return MAILSMTP_NO_ERROR;
+}
+
+int mailsmtp_reset(mailsmtp * session)
+{
+  char command[SMTP_STRING_SIZE];
+  int r;
+
+  snprintf(command, SMTP_STRING_SIZE, "RSET\r\n");
+  r = send_command(session, command);
+  if (r == -1)
+    return MAILSMTP_ERROR_STREAM;
+  r = read_response(session);
+  if (r == 0)
+    return MAILSMTP_ERROR_STREAM;
+  
+  return MAILSMTP_NO_ERROR;
+}
