@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailsmtp_socket.c,v 1.12 2005/06/01 12:22:21 smarinier Exp $
+ * $Id: mailsmtp_socket.c,v 1.13 2006/02/15 17:57:14 colinleroy Exp $
  */
 
 #include "mailsmtp_socket.h"
@@ -92,7 +92,7 @@ int mailsmtp_socket_starttls(mailsmtp * session) {
   if (fd == -1)
     return MAILSMTP_ERROR_STREAM;
 
-  new_low = mailstream_low_ssl_open(fd);
+  new_low = mailstream_low_tls_open(fd);
   if (new_low == NULL)
     return MAILSMTP_ERROR_STREAM;
 
